# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class DjStripePaymentIntent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'djstripe_id': 'int',
        'cancellation_reason': 'StripePaymentIntentCancellationReason',
        'charges': 'list[DjStripeCharge]',
        'setup_future_usage': 'StripeIntentUsage',
        'djstripe_created': 'datetime',
        'djstripe_updated': 'datetime',
        'id': 'str',
        'livemode': 'bool',
        'created': 'datetime',
        'metadata': 'dict(str, object)',
        'amount': 'int',
        'amount_capturable': 'int',
        'amount_received': 'int',
        'canceled_at': 'datetime',
        'capture_method': 'StripeConfirmationMethod',
        'client_secret': 'str',
        'confirmation_method': 'StripeConfirmationMethod',
        'currency': 'str',
        'description': 'str',
        'last_payment_error': 'dict(str, object)',
        'next_action': 'dict(str, object)',
        'payment_method_types': 'dict(str, object)',
        'receipt_email': 'str',
        'shipping': 'dict(str, object)',
        'statement_descriptor': 'str',
        'status': 'StripePaymentIntentStatus',
        'transfer_data': 'dict(str, object)',
        'transfer_group': 'str',
        'djstripe_owner_account': 'str',
        'customer': 'str',
        'on_behalf_of': 'str',
        'payment_method': 'str'
    }

    attribute_map = {
        'djstripe_id': 'djstripe_id',
        'cancellation_reason': 'cancellation_reason',
        'charges': 'charges',
        'setup_future_usage': 'setup_future_usage',
        'djstripe_created': 'djstripe_created',
        'djstripe_updated': 'djstripe_updated',
        'id': 'id',
        'livemode': 'livemode',
        'created': 'created',
        'metadata': 'metadata',
        'amount': 'amount',
        'amount_capturable': 'amount_capturable',
        'amount_received': 'amount_received',
        'canceled_at': 'canceled_at',
        'capture_method': 'capture_method',
        'client_secret': 'client_secret',
        'confirmation_method': 'confirmation_method',
        'currency': 'currency',
        'description': 'description',
        'last_payment_error': 'last_payment_error',
        'next_action': 'next_action',
        'payment_method_types': 'payment_method_types',
        'receipt_email': 'receipt_email',
        'shipping': 'shipping',
        'statement_descriptor': 'statement_descriptor',
        'status': 'status',
        'transfer_data': 'transfer_data',
        'transfer_group': 'transfer_group',
        'djstripe_owner_account': 'djstripe_owner_account',
        'customer': 'customer',
        'on_behalf_of': 'on_behalf_of',
        'payment_method': 'payment_method'
    }

    def __init__(self, djstripe_id=None, cancellation_reason=None, charges=None, setup_future_usage=None, djstripe_created=None, djstripe_updated=None, id=None, livemode=None, created=None, metadata=None, amount=None, amount_capturable=None, amount_received=None, canceled_at=None, capture_method=None, client_secret=None, confirmation_method=None, currency=None, description=None, last_payment_error=None, next_action=None, payment_method_types=None, receipt_email=None, shipping=None, statement_descriptor=None, status=None, transfer_data=None, transfer_group=None, djstripe_owner_account=None, customer=None, on_behalf_of=None, payment_method=None, local_vars_configuration=None):  # noqa: E501
        """DjStripePaymentIntent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._djstripe_id = None
        self._cancellation_reason = None
        self._charges = None
        self._setup_future_usage = None
        self._djstripe_created = None
        self._djstripe_updated = None
        self._id = None
        self._livemode = None
        self._created = None
        self._metadata = None
        self._amount = None
        self._amount_capturable = None
        self._amount_received = None
        self._canceled_at = None
        self._capture_method = None
        self._client_secret = None
        self._confirmation_method = None
        self._currency = None
        self._description = None
        self._last_payment_error = None
        self._next_action = None
        self._payment_method_types = None
        self._receipt_email = None
        self._shipping = None
        self._statement_descriptor = None
        self._status = None
        self._transfer_data = None
        self._transfer_group = None
        self._djstripe_owner_account = None
        self._customer = None
        self._on_behalf_of = None
        self._payment_method = None
        self.discriminator = None

        self.djstripe_id = djstripe_id
        self.cancellation_reason = cancellation_reason
        self.charges = charges
        self.setup_future_usage = setup_future_usage
        self.djstripe_created = djstripe_created
        self.djstripe_updated = djstripe_updated
        self.id = id
        self.livemode = livemode
        self.created = created
        self.metadata = metadata
        self.amount = amount
        self.amount_capturable = amount_capturable
        self.amount_received = amount_received
        self.canceled_at = canceled_at
        self.capture_method = capture_method
        self.client_secret = client_secret
        self.confirmation_method = confirmation_method
        self.currency = currency
        if description is not None:
            self.description = description
        self.last_payment_error = last_payment_error
        self.next_action = next_action
        self.payment_method_types = payment_method_types
        if receipt_email is not None:
            self.receipt_email = receipt_email
        self.shipping = shipping
        if statement_descriptor is not None:
            self.statement_descriptor = statement_descriptor
        self.status = status
        self.transfer_data = transfer_data
        if transfer_group is not None:
            self.transfer_group = transfer_group
        self.djstripe_owner_account = djstripe_owner_account
        self.customer = customer
        self.on_behalf_of = on_behalf_of
        self.payment_method = payment_method

    @property
    def djstripe_id(self):
        """Gets the djstripe_id of this DjStripePaymentIntent.  # noqa: E501


        :return: The djstripe_id of this DjStripePaymentIntent.  # noqa: E501
        :rtype: int
        """
        return self._djstripe_id

    @djstripe_id.setter
    def djstripe_id(self, djstripe_id):
        """Sets the djstripe_id of this DjStripePaymentIntent.


        :param djstripe_id: The djstripe_id of this DjStripePaymentIntent.  # noqa: E501
        :type djstripe_id: int
        """
        if self.local_vars_configuration.client_side_validation and djstripe_id is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_id`, must not be `None`")  # noqa: E501

        self._djstripe_id = djstripe_id

    @property
    def cancellation_reason(self):
        """Gets the cancellation_reason of this DjStripePaymentIntent.  # noqa: E501


        :return: The cancellation_reason of this DjStripePaymentIntent.  # noqa: E501
        :rtype: StripePaymentIntentCancellationReason
        """
        return self._cancellation_reason

    @cancellation_reason.setter
    def cancellation_reason(self, cancellation_reason):
        """Sets the cancellation_reason of this DjStripePaymentIntent.


        :param cancellation_reason: The cancellation_reason of this DjStripePaymentIntent.  # noqa: E501
        :type cancellation_reason: StripePaymentIntentCancellationReason
        """
        if self.local_vars_configuration.client_side_validation and cancellation_reason is None:  # noqa: E501
            raise ValueError("Invalid value for `cancellation_reason`, must not be `None`")  # noqa: E501

        self._cancellation_reason = cancellation_reason

    @property
    def charges(self):
        """Gets the charges of this DjStripePaymentIntent.  # noqa: E501


        :return: The charges of this DjStripePaymentIntent.  # noqa: E501
        :rtype: list[DjStripeCharge]
        """
        return self._charges

    @charges.setter
    def charges(self, charges):
        """Sets the charges of this DjStripePaymentIntent.


        :param charges: The charges of this DjStripePaymentIntent.  # noqa: E501
        :type charges: list[DjStripeCharge]
        """
        if self.local_vars_configuration.client_side_validation and charges is None:  # noqa: E501
            raise ValueError("Invalid value for `charges`, must not be `None`")  # noqa: E501

        self._charges = charges

    @property
    def setup_future_usage(self):
        """Gets the setup_future_usage of this DjStripePaymentIntent.  # noqa: E501


        :return: The setup_future_usage of this DjStripePaymentIntent.  # noqa: E501
        :rtype: StripeIntentUsage
        """
        return self._setup_future_usage

    @setup_future_usage.setter
    def setup_future_usage(self, setup_future_usage):
        """Sets the setup_future_usage of this DjStripePaymentIntent.


        :param setup_future_usage: The setup_future_usage of this DjStripePaymentIntent.  # noqa: E501
        :type setup_future_usage: StripeIntentUsage
        """
        if self.local_vars_configuration.client_side_validation and setup_future_usage is None:  # noqa: E501
            raise ValueError("Invalid value for `setup_future_usage`, must not be `None`")  # noqa: E501

        self._setup_future_usage = setup_future_usage

    @property
    def djstripe_created(self):
        """Gets the djstripe_created of this DjStripePaymentIntent.  # noqa: E501


        :return: The djstripe_created of this DjStripePaymentIntent.  # noqa: E501
        :rtype: datetime
        """
        return self._djstripe_created

    @djstripe_created.setter
    def djstripe_created(self, djstripe_created):
        """Sets the djstripe_created of this DjStripePaymentIntent.


        :param djstripe_created: The djstripe_created of this DjStripePaymentIntent.  # noqa: E501
        :type djstripe_created: datetime
        """
        if self.local_vars_configuration.client_side_validation and djstripe_created is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_created`, must not be `None`")  # noqa: E501

        self._djstripe_created = djstripe_created

    @property
    def djstripe_updated(self):
        """Gets the djstripe_updated of this DjStripePaymentIntent.  # noqa: E501


        :return: The djstripe_updated of this DjStripePaymentIntent.  # noqa: E501
        :rtype: datetime
        """
        return self._djstripe_updated

    @djstripe_updated.setter
    def djstripe_updated(self, djstripe_updated):
        """Sets the djstripe_updated of this DjStripePaymentIntent.


        :param djstripe_updated: The djstripe_updated of this DjStripePaymentIntent.  # noqa: E501
        :type djstripe_updated: datetime
        """
        if self.local_vars_configuration.client_side_validation and djstripe_updated is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_updated`, must not be `None`")  # noqa: E501

        self._djstripe_updated = djstripe_updated

    @property
    def id(self):
        """Gets the id of this DjStripePaymentIntent.  # noqa: E501


        :return: The id of this DjStripePaymentIntent.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DjStripePaymentIntent.


        :param id: The id of this DjStripePaymentIntent.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                id is not None and len(id) > 255):
            raise ValueError("Invalid value for `id`, length must be less than or equal to `255`")  # noqa: E501

        self._id = id

    @property
    def livemode(self):
        """Gets the livemode of this DjStripePaymentIntent.  # noqa: E501

        Null here indicates that the livemode status is unknown or was previously unrecorded. Otherwise, this field indicates whether this record comes from Stripe test mode or live mode operation.  # noqa: E501

        :return: The livemode of this DjStripePaymentIntent.  # noqa: E501
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """Sets the livemode of this DjStripePaymentIntent.

        Null here indicates that the livemode status is unknown or was previously unrecorded. Otherwise, this field indicates whether this record comes from Stripe test mode or live mode operation.  # noqa: E501

        :param livemode: The livemode of this DjStripePaymentIntent.  # noqa: E501
        :type livemode: bool
        """

        self._livemode = livemode

    @property
    def created(self):
        """Gets the created of this DjStripePaymentIntent.  # noqa: E501

        The datetime this object was created in stripe.  # noqa: E501

        :return: The created of this DjStripePaymentIntent.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this DjStripePaymentIntent.

        The datetime this object was created in stripe.  # noqa: E501

        :param created: The created of this DjStripePaymentIntent.  # noqa: E501
        :type created: datetime
        """

        self._created = created

    @property
    def metadata(self):
        """Gets the metadata of this DjStripePaymentIntent.  # noqa: E501

        A set of key/value pairs that you can attach to an object. It can be useful for storing additional information about an object in a structured format.  # noqa: E501

        :return: The metadata of this DjStripePaymentIntent.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this DjStripePaymentIntent.

        A set of key/value pairs that you can attach to an object. It can be useful for storing additional information about an object in a structured format.  # noqa: E501

        :param metadata: The metadata of this DjStripePaymentIntent.  # noqa: E501
        :type metadata: dict(str, object)
        """

        self._metadata = metadata

    @property
    def amount(self):
        """Gets the amount of this DjStripePaymentIntent.  # noqa: E501

        Amount (in cents) intended to be collected by this PaymentIntent.  # noqa: E501

        :return: The amount of this DjStripePaymentIntent.  # noqa: E501
        :rtype: int
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this DjStripePaymentIntent.

        Amount (in cents) intended to be collected by this PaymentIntent.  # noqa: E501

        :param amount: The amount of this DjStripePaymentIntent.  # noqa: E501
        :type amount: int
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                amount is not None and amount > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `amount`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                amount is not None and amount < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `amount`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._amount = amount

    @property
    def amount_capturable(self):
        """Gets the amount_capturable of this DjStripePaymentIntent.  # noqa: E501

        Amount (in cents) that can be captured from this PaymentIntent.  # noqa: E501

        :return: The amount_capturable of this DjStripePaymentIntent.  # noqa: E501
        :rtype: int
        """
        return self._amount_capturable

    @amount_capturable.setter
    def amount_capturable(self, amount_capturable):
        """Sets the amount_capturable of this DjStripePaymentIntent.

        Amount (in cents) that can be captured from this PaymentIntent.  # noqa: E501

        :param amount_capturable: The amount_capturable of this DjStripePaymentIntent.  # noqa: E501
        :type amount_capturable: int
        """
        if self.local_vars_configuration.client_side_validation and amount_capturable is None:  # noqa: E501
            raise ValueError("Invalid value for `amount_capturable`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                amount_capturable is not None and amount_capturable > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `amount_capturable`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                amount_capturable is not None and amount_capturable < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `amount_capturable`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._amount_capturable = amount_capturable

    @property
    def amount_received(self):
        """Gets the amount_received of this DjStripePaymentIntent.  # noqa: E501

        Amount (in cents) that was collected by this PaymentIntent.  # noqa: E501

        :return: The amount_received of this DjStripePaymentIntent.  # noqa: E501
        :rtype: int
        """
        return self._amount_received

    @amount_received.setter
    def amount_received(self, amount_received):
        """Sets the amount_received of this DjStripePaymentIntent.

        Amount (in cents) that was collected by this PaymentIntent.  # noqa: E501

        :param amount_received: The amount_received of this DjStripePaymentIntent.  # noqa: E501
        :type amount_received: int
        """
        if self.local_vars_configuration.client_side_validation and amount_received is None:  # noqa: E501
            raise ValueError("Invalid value for `amount_received`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                amount_received is not None and amount_received > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `amount_received`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                amount_received is not None and amount_received < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `amount_received`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._amount_received = amount_received

    @property
    def canceled_at(self):
        """Gets the canceled_at of this DjStripePaymentIntent.  # noqa: E501

        Populated when status is canceled, this is the time at which the PaymentIntent was canceled. Measured in seconds since the Unix epoch.  # noqa: E501

        :return: The canceled_at of this DjStripePaymentIntent.  # noqa: E501
        :rtype: datetime
        """
        return self._canceled_at

    @canceled_at.setter
    def canceled_at(self, canceled_at):
        """Sets the canceled_at of this DjStripePaymentIntent.

        Populated when status is canceled, this is the time at which the PaymentIntent was canceled. Measured in seconds since the Unix epoch.  # noqa: E501

        :param canceled_at: The canceled_at of this DjStripePaymentIntent.  # noqa: E501
        :type canceled_at: datetime
        """

        self._canceled_at = canceled_at

    @property
    def capture_method(self):
        """Gets the capture_method of this DjStripePaymentIntent.  # noqa: E501

        Capture method of this PaymentIntent, one of automatic or manual.  # noqa: E501

        :return: The capture_method of this DjStripePaymentIntent.  # noqa: E501
        :rtype: StripeConfirmationMethod
        """
        return self._capture_method

    @capture_method.setter
    def capture_method(self, capture_method):
        """Sets the capture_method of this DjStripePaymentIntent.

        Capture method of this PaymentIntent, one of automatic or manual.  # noqa: E501

        :param capture_method: The capture_method of this DjStripePaymentIntent.  # noqa: E501
        :type capture_method: StripeConfirmationMethod
        """

        self._capture_method = capture_method

    @property
    def client_secret(self):
        """Gets the client_secret of this DjStripePaymentIntent.  # noqa: E501

        The client secret of this PaymentIntent. Used for client-side retrieval using a publishable key.  # noqa: E501

        :return: The client_secret of this DjStripePaymentIntent.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this DjStripePaymentIntent.

        The client secret of this PaymentIntent. Used for client-side retrieval using a publishable key.  # noqa: E501

        :param client_secret: The client_secret of this DjStripePaymentIntent.  # noqa: E501
        :type client_secret: str
        """
        if self.local_vars_configuration.client_side_validation and client_secret is None:  # noqa: E501
            raise ValueError("Invalid value for `client_secret`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                client_secret is not None and len(client_secret) > 5000):
            raise ValueError("Invalid value for `client_secret`, length must be less than or equal to `5000`")  # noqa: E501

        self._client_secret = client_secret

    @property
    def confirmation_method(self):
        """Gets the confirmation_method of this DjStripePaymentIntent.  # noqa: E501

        Confirmation method of this PaymentIntent, one of manual or automatic.  # noqa: E501

        :return: The confirmation_method of this DjStripePaymentIntent.  # noqa: E501
        :rtype: StripeConfirmationMethod
        """
        return self._confirmation_method

    @confirmation_method.setter
    def confirmation_method(self, confirmation_method):
        """Sets the confirmation_method of this DjStripePaymentIntent.

        Confirmation method of this PaymentIntent, one of manual or automatic.  # noqa: E501

        :param confirmation_method: The confirmation_method of this DjStripePaymentIntent.  # noqa: E501
        :type confirmation_method: StripeConfirmationMethod
        """

        self._confirmation_method = confirmation_method

    @property
    def currency(self):
        """Gets the currency of this DjStripePaymentIntent.  # noqa: E501

        Three-letter ISO currency code  # noqa: E501

        :return: The currency of this DjStripePaymentIntent.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this DjStripePaymentIntent.

        Three-letter ISO currency code  # noqa: E501

        :param currency: The currency of this DjStripePaymentIntent.  # noqa: E501
        :type currency: str
        """
        if self.local_vars_configuration.client_side_validation and currency is None:  # noqa: E501
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                currency is not None and len(currency) > 3):
            raise ValueError("Invalid value for `currency`, length must be less than or equal to `3`")  # noqa: E501

        self._currency = currency

    @property
    def description(self):
        """Gets the description of this DjStripePaymentIntent.  # noqa: E501

        An arbitrary string attached to the object. Often useful for displaying to users.  # noqa: E501

        :return: The description of this DjStripePaymentIntent.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DjStripePaymentIntent.

        An arbitrary string attached to the object. Often useful for displaying to users.  # noqa: E501

        :param description: The description of this DjStripePaymentIntent.  # noqa: E501
        :type description: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 1000):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `1000`")  # noqa: E501

        self._description = description

    @property
    def last_payment_error(self):
        """Gets the last_payment_error of this DjStripePaymentIntent.  # noqa: E501

        The payment error encountered in the previous PaymentIntent confirmation.  # noqa: E501

        :return: The last_payment_error of this DjStripePaymentIntent.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._last_payment_error

    @last_payment_error.setter
    def last_payment_error(self, last_payment_error):
        """Sets the last_payment_error of this DjStripePaymentIntent.

        The payment error encountered in the previous PaymentIntent confirmation.  # noqa: E501

        :param last_payment_error: The last_payment_error of this DjStripePaymentIntent.  # noqa: E501
        :type last_payment_error: dict(str, object)
        """

        self._last_payment_error = last_payment_error

    @property
    def next_action(self):
        """Gets the next_action of this DjStripePaymentIntent.  # noqa: E501

        If present, this property tells you what actions you need to take in order for your customer to fulfill a payment using the provided source.  # noqa: E501

        :return: The next_action of this DjStripePaymentIntent.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._next_action

    @next_action.setter
    def next_action(self, next_action):
        """Sets the next_action of this DjStripePaymentIntent.

        If present, this property tells you what actions you need to take in order for your customer to fulfill a payment using the provided source.  # noqa: E501

        :param next_action: The next_action of this DjStripePaymentIntent.  # noqa: E501
        :type next_action: dict(str, object)
        """

        self._next_action = next_action

    @property
    def payment_method_types(self):
        """Gets the payment_method_types of this DjStripePaymentIntent.  # noqa: E501

        The list of payment method types (e.g. card) that this PaymentIntent is allowed to use.  # noqa: E501

        :return: The payment_method_types of this DjStripePaymentIntent.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._payment_method_types

    @payment_method_types.setter
    def payment_method_types(self, payment_method_types):
        """Sets the payment_method_types of this DjStripePaymentIntent.

        The list of payment method types (e.g. card) that this PaymentIntent is allowed to use.  # noqa: E501

        :param payment_method_types: The payment_method_types of this DjStripePaymentIntent.  # noqa: E501
        :type payment_method_types: dict(str, object)
        """
        if self.local_vars_configuration.client_side_validation and payment_method_types is None:  # noqa: E501
            raise ValueError("Invalid value for `payment_method_types`, must not be `None`")  # noqa: E501

        self._payment_method_types = payment_method_types

    @property
    def receipt_email(self):
        """Gets the receipt_email of this DjStripePaymentIntent.  # noqa: E501

        Email address that the receipt for the resulting payment will be sent to.  # noqa: E501

        :return: The receipt_email of this DjStripePaymentIntent.  # noqa: E501
        :rtype: str
        """
        return self._receipt_email

    @receipt_email.setter
    def receipt_email(self, receipt_email):
        """Sets the receipt_email of this DjStripePaymentIntent.

        Email address that the receipt for the resulting payment will be sent to.  # noqa: E501

        :param receipt_email: The receipt_email of this DjStripePaymentIntent.  # noqa: E501
        :type receipt_email: str
        """
        if (self.local_vars_configuration.client_side_validation and
                receipt_email is not None and len(receipt_email) > 255):
            raise ValueError("Invalid value for `receipt_email`, length must be less than or equal to `255`")  # noqa: E501

        self._receipt_email = receipt_email

    @property
    def shipping(self):
        """Gets the shipping of this DjStripePaymentIntent.  # noqa: E501

        Shipping information for this PaymentIntent.  # noqa: E501

        :return: The shipping of this DjStripePaymentIntent.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._shipping

    @shipping.setter
    def shipping(self, shipping):
        """Sets the shipping of this DjStripePaymentIntent.

        Shipping information for this PaymentIntent.  # noqa: E501

        :param shipping: The shipping of this DjStripePaymentIntent.  # noqa: E501
        :type shipping: dict(str, object)
        """

        self._shipping = shipping

    @property
    def statement_descriptor(self):
        """Gets the statement_descriptor of this DjStripePaymentIntent.  # noqa: E501

        For non-card charges, you can use this value as the complete description that appears on your customers' statements. Must contain at least one letter, maximum 22 characters.  # noqa: E501

        :return: The statement_descriptor of this DjStripePaymentIntent.  # noqa: E501
        :rtype: str
        """
        return self._statement_descriptor

    @statement_descriptor.setter
    def statement_descriptor(self, statement_descriptor):
        """Sets the statement_descriptor of this DjStripePaymentIntent.

        For non-card charges, you can use this value as the complete description that appears on your customers' statements. Must contain at least one letter, maximum 22 characters.  # noqa: E501

        :param statement_descriptor: The statement_descriptor of this DjStripePaymentIntent.  # noqa: E501
        :type statement_descriptor: str
        """
        if (self.local_vars_configuration.client_side_validation and
                statement_descriptor is not None and len(statement_descriptor) > 22):
            raise ValueError("Invalid value for `statement_descriptor`, length must be less than or equal to `22`")  # noqa: E501

        self._statement_descriptor = statement_descriptor

    @property
    def status(self):
        """Gets the status of this DjStripePaymentIntent.  # noqa: E501

        Status of this PaymentIntent, one of requires_payment_method, requires_confirmation, requires_action, processing, requires_capture, canceled, or succeeded. You can read more about PaymentIntent statuses here.  # noqa: E501

        :return: The status of this DjStripePaymentIntent.  # noqa: E501
        :rtype: StripePaymentIntentStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DjStripePaymentIntent.

        Status of this PaymentIntent, one of requires_payment_method, requires_confirmation, requires_action, processing, requires_capture, canceled, or succeeded. You can read more about PaymentIntent statuses here.  # noqa: E501

        :param status: The status of this DjStripePaymentIntent.  # noqa: E501
        :type status: StripePaymentIntentStatus
        """

        self._status = status

    @property
    def transfer_data(self):
        """Gets the transfer_data of this DjStripePaymentIntent.  # noqa: E501

        The data with which to automatically create a Transfer when the payment is finalized. See the PaymentIntents Connect usage guide for details.  # noqa: E501

        :return: The transfer_data of this DjStripePaymentIntent.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._transfer_data

    @transfer_data.setter
    def transfer_data(self, transfer_data):
        """Sets the transfer_data of this DjStripePaymentIntent.

        The data with which to automatically create a Transfer when the payment is finalized. See the PaymentIntents Connect usage guide for details.  # noqa: E501

        :param transfer_data: The transfer_data of this DjStripePaymentIntent.  # noqa: E501
        :type transfer_data: dict(str, object)
        """

        self._transfer_data = transfer_data

    @property
    def transfer_group(self):
        """Gets the transfer_group of this DjStripePaymentIntent.  # noqa: E501

        A string that identifies the resulting payment as part of a group. See the PaymentIntents Connect usage guide for details.  # noqa: E501

        :return: The transfer_group of this DjStripePaymentIntent.  # noqa: E501
        :rtype: str
        """
        return self._transfer_group

    @transfer_group.setter
    def transfer_group(self, transfer_group):
        """Sets the transfer_group of this DjStripePaymentIntent.

        A string that identifies the resulting payment as part of a group. See the PaymentIntents Connect usage guide for details.  # noqa: E501

        :param transfer_group: The transfer_group of this DjStripePaymentIntent.  # noqa: E501
        :type transfer_group: str
        """
        if (self.local_vars_configuration.client_side_validation and
                transfer_group is not None and len(transfer_group) > 255):
            raise ValueError("Invalid value for `transfer_group`, length must be less than or equal to `255`")  # noqa: E501

        self._transfer_group = transfer_group

    @property
    def djstripe_owner_account(self):
        """Gets the djstripe_owner_account of this DjStripePaymentIntent.  # noqa: E501

        The Stripe Account this object belongs to.  # noqa: E501

        :return: The djstripe_owner_account of this DjStripePaymentIntent.  # noqa: E501
        :rtype: str
        """
        return self._djstripe_owner_account

    @djstripe_owner_account.setter
    def djstripe_owner_account(self, djstripe_owner_account):
        """Sets the djstripe_owner_account of this DjStripePaymentIntent.

        The Stripe Account this object belongs to.  # noqa: E501

        :param djstripe_owner_account: The djstripe_owner_account of this DjStripePaymentIntent.  # noqa: E501
        :type djstripe_owner_account: str
        """

        self._djstripe_owner_account = djstripe_owner_account

    @property
    def customer(self):
        """Gets the customer of this DjStripePaymentIntent.  # noqa: E501

        Customer this PaymentIntent is for if one exists.  # noqa: E501

        :return: The customer of this DjStripePaymentIntent.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this DjStripePaymentIntent.

        Customer this PaymentIntent is for if one exists.  # noqa: E501

        :param customer: The customer of this DjStripePaymentIntent.  # noqa: E501
        :type customer: str
        """

        self._customer = customer

    @property
    def on_behalf_of(self):
        """Gets the on_behalf_of of this DjStripePaymentIntent.  # noqa: E501

        The account (if any) for which the funds of the PaymentIntent are intended.  # noqa: E501

        :return: The on_behalf_of of this DjStripePaymentIntent.  # noqa: E501
        :rtype: str
        """
        return self._on_behalf_of

    @on_behalf_of.setter
    def on_behalf_of(self, on_behalf_of):
        """Sets the on_behalf_of of this DjStripePaymentIntent.

        The account (if any) for which the funds of the PaymentIntent are intended.  # noqa: E501

        :param on_behalf_of: The on_behalf_of of this DjStripePaymentIntent.  # noqa: E501
        :type on_behalf_of: str
        """

        self._on_behalf_of = on_behalf_of

    @property
    def payment_method(self):
        """Gets the payment_method of this DjStripePaymentIntent.  # noqa: E501

        Payment method used in this PaymentIntent.  # noqa: E501

        :return: The payment_method of this DjStripePaymentIntent.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this DjStripePaymentIntent.

        Payment method used in this PaymentIntent.  # noqa: E501

        :param payment_method: The payment_method of this DjStripePaymentIntent.  # noqa: E501
        :type payment_method: str
        """

        self._payment_method = payment_method

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DjStripePaymentIntent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DjStripePaymentIntent):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.dj_stripe_checkout_session import DjStripeCheckoutSession  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestDjStripeCheckoutSession(unittest.TestCase):
    """DjStripeCheckoutSession unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DjStripeCheckoutSession
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.dj_stripe_checkout_session.DjStripeCheckoutSession()  # noqa: E501
        if include_optional :
            return DjStripeCheckoutSession(
                djstripe_id = 56, 
                billing_address_collection = 'auto', 
                mode = 'payment', 
                submit_type = 'auto', 
                djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                id = '', 
                livemode = True, 
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                metadata = {
                    'key' : null
                    }, 
                description = '', 
                cancel_url = '', 
                client_reference_id = '', 
                customer_email = '', 
                display_items = {
                    'key' : null
                    }, 
                locale = '', 
                payment_method_types = {
                    'key' : null
                    }, 
                success_url = '', 
                djstripe_owner_account = '', 
                customer = '', 
                payment_intent = '', 
                subscription = ''
            )
        else :
            return DjStripeCheckoutSession(
                djstripe_id = 56,
                billing_address_collection = 'auto',
                mode = 'payment',
                submit_type = 'auto',
                djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                payment_method_types = {
                    'key' : null
                    },
        )

    def testDjStripeCheckoutSession(self):
        """Test DjStripeCheckoutSession"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoPrintSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'octoprint_enabled': 'bool',
        'events_enabled': 'bool',
        'sync_gcode': 'bool',
        'sync_printer_profiles': 'bool',
        'sync_backups': 'bool',
        'auto_backup': 'str',
        'updated_dt': 'datetime',
        'octoprint_server': 'int'
    }

    attribute_map = {
        'id': 'id',
        'octoprint_enabled': 'octoprint_enabled',
        'events_enabled': 'events_enabled',
        'sync_gcode': 'sync_gcode',
        'sync_printer_profiles': 'sync_printer_profiles',
        'sync_backups': 'sync_backups',
        'auto_backup': 'auto_backup',
        'updated_dt': 'updated_dt',
        'octoprint_server': 'octoprint_server'
    }

    def __init__(self, id=None, octoprint_enabled=None, events_enabled=None, sync_gcode=None, sync_printer_profiles=None, sync_backups=None, auto_backup=None, updated_dt=None, octoprint_server=None, local_vars_configuration=None):  # noqa: E501
        """OctoPrintSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._octoprint_enabled = None
        self._events_enabled = None
        self._sync_gcode = None
        self._sync_printer_profiles = None
        self._sync_backups = None
        self._auto_backup = None
        self._updated_dt = None
        self._octoprint_server = None
        self.discriminator = None

        self.id = id
        if octoprint_enabled is not None:
            self.octoprint_enabled = octoprint_enabled
        if events_enabled is not None:
            self.events_enabled = events_enabled
        if sync_gcode is not None:
            self.sync_gcode = sync_gcode
        if sync_printer_profiles is not None:
            self.sync_printer_profiles = sync_printer_profiles
        if sync_backups is not None:
            self.sync_backups = sync_backups
        if auto_backup is not None:
            self.auto_backup = auto_backup
        self.updated_dt = updated_dt
        self.octoprint_server = octoprint_server

    @property
    def id(self):
        """Gets the id of this OctoPrintSettings.  # noqa: E501


        :return: The id of this OctoPrintSettings.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OctoPrintSettings.


        :param id: The id of this OctoPrintSettings.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def octoprint_enabled(self):
        """Gets the octoprint_enabled of this OctoPrintSettings.  # noqa: E501

        Start OctoPrint service  # noqa: E501

        :return: The octoprint_enabled of this OctoPrintSettings.  # noqa: E501
        :rtype: bool
        """
        return self._octoprint_enabled

    @octoprint_enabled.setter
    def octoprint_enabled(self, octoprint_enabled):
        """Sets the octoprint_enabled of this OctoPrintSettings.

        Start OctoPrint service  # noqa: E501

        :param octoprint_enabled: The octoprint_enabled of this OctoPrintSettings.  # noqa: E501
        :type octoprint_enabled: bool
        """

        self._octoprint_enabled = octoprint_enabled

    @property
    def events_enabled(self):
        """Gets the events_enabled of this OctoPrintSettings.  # noqa: E501

        Send OctoPrint events related to print job status/progress to PrintNanny Cloud https://docs.octoprint.org/en/master/events/index.html  # noqa: E501

        :return: The events_enabled of this OctoPrintSettings.  # noqa: E501
        :rtype: bool
        """
        return self._events_enabled

    @events_enabled.setter
    def events_enabled(self, events_enabled):
        """Sets the events_enabled of this OctoPrintSettings.

        Send OctoPrint events related to print job status/progress to PrintNanny Cloud https://docs.octoprint.org/en/master/events/index.html  # noqa: E501

        :param events_enabled: The events_enabled of this OctoPrintSettings.  # noqa: E501
        :type events_enabled: bool
        """

        self._events_enabled = events_enabled

    @property
    def sync_gcode(self):
        """Gets the sync_gcode of this OctoPrintSettings.  # noqa: E501

        Sync Gcode files to/from PrintNanny Cloud  # noqa: E501

        :return: The sync_gcode of this OctoPrintSettings.  # noqa: E501
        :rtype: bool
        """
        return self._sync_gcode

    @sync_gcode.setter
    def sync_gcode(self, sync_gcode):
        """Sets the sync_gcode of this OctoPrintSettings.

        Sync Gcode files to/from PrintNanny Cloud  # noqa: E501

        :param sync_gcode: The sync_gcode of this OctoPrintSettings.  # noqa: E501
        :type sync_gcode: bool
        """

        self._sync_gcode = sync_gcode

    @property
    def sync_printer_profiles(self):
        """Gets the sync_printer_profiles of this OctoPrintSettings.  # noqa: E501

        Sync Printer Profiles to/from PrintNanny Cloud  # noqa: E501

        :return: The sync_printer_profiles of this OctoPrintSettings.  # noqa: E501
        :rtype: bool
        """
        return self._sync_printer_profiles

    @sync_printer_profiles.setter
    def sync_printer_profiles(self, sync_printer_profiles):
        """Sets the sync_printer_profiles of this OctoPrintSettings.

        Sync Printer Profiles to/from PrintNanny Cloud  # noqa: E501

        :param sync_printer_profiles: The sync_printer_profiles of this OctoPrintSettings.  # noqa: E501
        :type sync_printer_profiles: bool
        """

        self._sync_printer_profiles = sync_printer_profiles

    @property
    def sync_backups(self):
        """Gets the sync_backups of this OctoPrintSettings.  # noqa: E501

        Upload OctoPrint backups to PrintNanny Cloud  # noqa: E501

        :return: The sync_backups of this OctoPrintSettings.  # noqa: E501
        :rtype: bool
        """
        return self._sync_backups

    @sync_backups.setter
    def sync_backups(self, sync_backups):
        """Sets the sync_backups of this OctoPrintSettings.

        Upload OctoPrint backups to PrintNanny Cloud  # noqa: E501

        :param sync_backups: The sync_backups of this OctoPrintSettings.  # noqa: E501
        :type sync_backups: bool
        """

        self._sync_backups = sync_backups

    @property
    def auto_backup(self):
        """Gets the auto_backup of this OctoPrintSettings.  # noqa: E501


        :return: The auto_backup of this OctoPrintSettings.  # noqa: E501
        :rtype: str
        """
        return self._auto_backup

    @auto_backup.setter
    def auto_backup(self, auto_backup):
        """Sets the auto_backup of this OctoPrintSettings.


        :param auto_backup: The auto_backup of this OctoPrintSettings.  # noqa: E501
        :type auto_backup: str
        """
        if (self.local_vars_configuration.client_side_validation and
                auto_backup is not None and len(auto_backup) > 64):
            raise ValueError("Invalid value for `auto_backup`, length must be less than or equal to `64`")  # noqa: E501

        self._auto_backup = auto_backup

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OctoPrintSettings.  # noqa: E501


        :return: The updated_dt of this OctoPrintSettings.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OctoPrintSettings.


        :param updated_dt: The updated_dt of this OctoPrintSettings.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def octoprint_server(self):
        """Gets the octoprint_server of this OctoPrintSettings.  # noqa: E501


        :return: The octoprint_server of this OctoPrintSettings.  # noqa: E501
        :rtype: int
        """
        return self._octoprint_server

    @octoprint_server.setter
    def octoprint_server(self, octoprint_server):
        """Sets the octoprint_server of this OctoPrintSettings.


        :param octoprint_server: The octoprint_server of this OctoPrintSettings.  # noqa: E501
        :type octoprint_server: int
        """
        if self.local_vars_configuration.client_side_validation and octoprint_server is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_server`, must not be `None`")  # noqa: E501

        self._octoprint_server = octoprint_server

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoPrintSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoPrintSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.webrtc_stream import WebrtcStream  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestWebrtcStream(unittest.TestCase):
    """WebrtcStream unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WebrtcStream
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.webrtc_stream.WebrtcStream()  # noqa: E501
        if include_optional :
            return WebrtcStream(
                active = True, 
                admin_port = 56, 
                admin_secret = '', 
                admin_url = '', 
                api_domain = '', 
                api_port = 56, 
                api_token = '', 
                api_url = '', 
                config_type = 'cloud', 
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                id = 56, 
                info = {
                    'key' : null
                    }, 
                is_admin = True, 
                pi = 56, 
                pt = 56, 
                rtp_domain = '', 
                video_rtp_port = 56, 
                data_rtp_port = 56, 
                rtpmap = '', 
                stream_pin = '', 
                stream_secret = '', 
                updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                ws_port = 56, 
                ws_url = ''
            )
        else :
            return WebrtcStream(
                admin_port = 56,
                admin_secret = '',
                admin_url = '',
                api_domain = '',
                api_port = 56,
                api_token = '',
                api_url = '',
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = 56,
                info = {
                    'key' : null
                    },
                is_admin = True,
                pi = 56,
                pt = 56,
                rtp_domain = '',
                video_rtp_port = 56,
                data_rtp_port = 56,
                rtpmap = '',
                stream_pin = '',
                stream_secret = '',
                updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                ws_port = 56,
                ws_url = '',
        )

    def testWebrtcStream(self):
        """Test WebrtcStream"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from printnanny_api_client.api.accounts_api import AccountsApi
from printnanny_api_client.api.alerts_api import AlertsApi
from printnanny_api_client.api.devices_api import DevicesApi
from printnanny_api_client.api.events_api import EventsApi
from printnanny_api_client.api.janus_api import JanusApi
from printnanny_api_client.api.octoprint_api import OctoprintApi
from printnanny_api_client.api.pis_api import PisApi
from printnanny_api_client.api.schema_api import SchemaApi
from printnanny_api_client.api.settings_api import SettingsApi
from printnanny_api_client.api.shop_api import ShopApi



# coding: utf-8

# flake8: noqa
"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from printnanny_api_client.models.callback_token_auth import CallbackTokenAuth
from printnanny_api_client.models.callback_token_auth_request import CallbackTokenAuthRequest
from printnanny_api_client.models.dj_stripe_charge import DjStripeCharge
from printnanny_api_client.models.dj_stripe_checkout_session import DjStripeCheckoutSession
from printnanny_api_client.models.dj_stripe_customer import DjStripeCustomer
from printnanny_api_client.models.dj_stripe_payment_intent import DjStripePaymentIntent
from printnanny_api_client.models.dj_stripe_price import DjStripePrice
from printnanny_api_client.models.dj_stripe_product import DjStripeProduct
from printnanny_api_client.models.email_alert_settings import EmailAlertSettings
from printnanny_api_client.models.email_alert_settings_request import EmailAlertSettingsRequest
from printnanny_api_client.models.email_auth import EmailAuth
from printnanny_api_client.models.email_auth_request import EmailAuthRequest
from printnanny_api_client.models.email_waitlist import EmailWaitlist
from printnanny_api_client.models.email_waitlist_request import EmailWaitlistRequest
from printnanny_api_client.models.error_detail import ErrorDetail
from printnanny_api_client.models.event_types_enum import EventTypesEnum
from printnanny_api_client.models.gcode_file import GcodeFile
from printnanny_api_client.models.janus_config_type import JanusConfigType
from printnanny_api_client.models.login_request import LoginRequest
from printnanny_api_client.models.nats_organization import NatsOrganization
from printnanny_api_client.models.nats_organization_request import NatsOrganizationRequest
from printnanny_api_client.models.nats_organization_user import NatsOrganizationUser
from printnanny_api_client.models.octo_print_backup import OctoPrintBackup
from printnanny_api_client.models.octo_print_client_status import OctoPrintClientStatus
from printnanny_api_client.models.octo_print_client_status_payload import OctoPrintClientStatusPayload
from printnanny_api_client.models.octo_print_client_status_payload_request import OctoPrintClientStatusPayloadRequest
from printnanny_api_client.models.octo_print_client_status_request import OctoPrintClientStatusRequest
from printnanny_api_client.models.octo_print_client_status_subject_pattern_enum import OctoPrintClientStatusSubjectPatternEnum
from printnanny_api_client.models.octo_print_client_status_type import OctoPrintClientStatusType
from printnanny_api_client.models.octo_print_print_job_payload import OctoPrintPrintJobPayload
from printnanny_api_client.models.octo_print_print_job_payload_request import OctoPrintPrintJobPayloadRequest
from printnanny_api_client.models.octo_print_print_job_status import OctoPrintPrintJobStatus
from printnanny_api_client.models.octo_print_print_job_status_request import OctoPrintPrintJobStatusRequest
from printnanny_api_client.models.octo_print_print_job_status_subject_pattern_enum import OctoPrintPrintJobStatusSubjectPatternEnum
from printnanny_api_client.models.octo_print_print_job_status_type import OctoPrintPrintJobStatusType
from printnanny_api_client.models.octo_print_printer_status import OctoPrintPrinterStatus
from printnanny_api_client.models.octo_print_printer_status_request import OctoPrintPrinterStatusRequest
from printnanny_api_client.models.octo_print_printer_status_subject_pattern_enum import OctoPrintPrinterStatusSubjectPatternEnum
from printnanny_api_client.models.octo_print_printer_status_type import OctoPrintPrinterStatusType
from printnanny_api_client.models.octo_print_server import OctoPrintServer
from printnanny_api_client.models.octo_print_server_request import OctoPrintServerRequest
from printnanny_api_client.models.octo_print_server_status import OctoPrintServerStatus
from printnanny_api_client.models.octo_print_server_status_request import OctoPrintServerStatusRequest
from printnanny_api_client.models.octo_print_server_status_subject_pattern_enum import OctoPrintServerStatusSubjectPatternEnum
from printnanny_api_client.models.octo_print_server_status_type import OctoPrintServerStatusType
from printnanny_api_client.models.octo_print_settings import OctoPrintSettings
from printnanny_api_client.models.octo_print_settings_request import OctoPrintSettingsRequest
from printnanny_api_client.models.octo_printer_profile import OctoPrinterProfile
from printnanny_api_client.models.octo_printer_profile_request import OctoPrinterProfileRequest
from printnanny_api_client.models.order import Order
from printnanny_api_client.models.order_checkout import OrderCheckout
from printnanny_api_client.models.order_checkout_request import OrderCheckoutRequest
from printnanny_api_client.models.order_status import OrderStatus
from printnanny_api_client.models.order_status_type import OrderStatusType
from printnanny_api_client.models.paginated_email_alert_settings_list import PaginatedEmailAlertSettingsList
from printnanny_api_client.models.paginated_gcode_file_list import PaginatedGcodeFileList
from printnanny_api_client.models.paginated_octo_print_backup_list import PaginatedOctoPrintBackupList
from printnanny_api_client.models.paginated_octo_print_server_list import PaginatedOctoPrintServerList
from printnanny_api_client.models.paginated_octo_print_settings_list import PaginatedOctoPrintSettingsList
from printnanny_api_client.models.paginated_octo_printer_profile_list import PaginatedOctoPrinterProfileList
from printnanny_api_client.models.paginated_pi_list import PaginatedPiList
from printnanny_api_client.models.paginated_pi_settings_list import PaginatedPiSettingsList
from printnanny_api_client.models.paginated_polymorphic_octo_print_event_list import PaginatedPolymorphicOctoPrintEventList
from printnanny_api_client.models.paginated_polymorphic_pi_command_list import PaginatedPolymorphicPiCommandList
from printnanny_api_client.models.paginated_polymorphic_pi_event_list import PaginatedPolymorphicPiEventList
from printnanny_api_client.models.paginated_polymorphic_pi_status_list import PaginatedPolymorphicPiStatusList
from printnanny_api_client.models.paginated_product_list import PaginatedProductList
from printnanny_api_client.models.paginated_system_info_list import PaginatedSystemInfoList
from printnanny_api_client.models.paginated_webrtc_stream_list import PaginatedWebrtcStreamList
from printnanny_api_client.models.password_change_request import PasswordChangeRequest
from printnanny_api_client.models.password_reset_confirm_request import PasswordResetConfirmRequest
from printnanny_api_client.models.password_reset_request import PasswordResetRequest
from printnanny_api_client.models.patched_email_alert_settings_request import PatchedEmailAlertSettingsRequest
from printnanny_api_client.models.patched_octo_print_server_request import PatchedOctoPrintServerRequest
from printnanny_api_client.models.patched_octo_print_settings_request import PatchedOctoPrintSettingsRequest
from printnanny_api_client.models.patched_octo_printer_profile_request import PatchedOctoPrinterProfileRequest
from printnanny_api_client.models.patched_pi_request import PatchedPiRequest
from printnanny_api_client.models.patched_pi_settings_request import PatchedPiSettingsRequest
from printnanny_api_client.models.patched_system_info_request import PatchedSystemInfoRequest
from printnanny_api_client.models.patched_user_request import PatchedUserRequest
from printnanny_api_client.models.patched_webrtc_stream_request import PatchedWebrtcStreamRequest
from printnanny_api_client.models.pi import Pi
from printnanny_api_client.models.pi_boot_command import PiBootCommand
from printnanny_api_client.models.pi_boot_command_request import PiBootCommandRequest
from printnanny_api_client.models.pi_boot_command_subject_pattern_enum import PiBootCommandSubjectPatternEnum
from printnanny_api_client.models.pi_boot_command_type import PiBootCommandType
from printnanny_api_client.models.pi_boot_status import PiBootStatus
from printnanny_api_client.models.pi_boot_status_request import PiBootStatusRequest
from printnanny_api_client.models.pi_boot_status_subject_pattern_enum import PiBootStatusSubjectPatternEnum
from printnanny_api_client.models.pi_boot_status_type import PiBootStatusType
from printnanny_api_client.models.pi_cam_command import PiCamCommand
from printnanny_api_client.models.pi_cam_command_request import PiCamCommandRequest
from printnanny_api_client.models.pi_cam_command_subject_pattern_enum import PiCamCommandSubjectPatternEnum
from printnanny_api_client.models.pi_cam_command_type import PiCamCommandType
from printnanny_api_client.models.pi_cam_status import PiCamStatus
from printnanny_api_client.models.pi_cam_status_request import PiCamStatusRequest
from printnanny_api_client.models.pi_cam_status_subject_pattern_enum import PiCamStatusSubjectPatternEnum
from printnanny_api_client.models.pi_cam_status_type import PiCamStatusType
from printnanny_api_client.models.pi_nats_app import PiNatsApp
from printnanny_api_client.models.pi_nats_app_request import PiNatsAppRequest
from printnanny_api_client.models.pi_request import PiRequest
from printnanny_api_client.models.pi_settings import PiSettings
from printnanny_api_client.models.pi_settings_request import PiSettingsRequest
from printnanny_api_client.models.pi_software_update_command import PiSoftwareUpdateCommand
from printnanny_api_client.models.pi_software_update_command_request import PiSoftwareUpdateCommandRequest
from printnanny_api_client.models.pi_software_update_command_subject_pattern_enum import PiSoftwareUpdateCommandSubjectPatternEnum
from printnanny_api_client.models.pi_software_update_command_type import PiSoftwareUpdateCommandType
from printnanny_api_client.models.pi_software_update_payload import PiSoftwareUpdatePayload
from printnanny_api_client.models.pi_software_update_payload_request import PiSoftwareUpdatePayloadRequest
from printnanny_api_client.models.pi_software_update_status import PiSoftwareUpdateStatus
from printnanny_api_client.models.pi_software_update_status_request import PiSoftwareUpdateStatusRequest
from printnanny_api_client.models.pi_software_update_status_subject_pattern_enum import PiSoftwareUpdateStatusSubjectPatternEnum
from printnanny_api_client.models.pi_software_update_status_type import PiSoftwareUpdateStatusType
from printnanny_api_client.models.pi_urls import PiUrls
from printnanny_api_client.models.polymorphic_octo_print_event import PolymorphicOctoPrintEvent
from printnanny_api_client.models.polymorphic_octo_print_event_request import PolymorphicOctoPrintEventRequest
from printnanny_api_client.models.polymorphic_pi_command import PolymorphicPiCommand
from printnanny_api_client.models.polymorphic_pi_command_request import PolymorphicPiCommandRequest
from printnanny_api_client.models.polymorphic_pi_event import PolymorphicPiEvent
from printnanny_api_client.models.polymorphic_pi_event_request import PolymorphicPiEventRequest
from printnanny_api_client.models.polymorphic_pi_status import PolymorphicPiStatus
from printnanny_api_client.models.polymorphic_pi_status_request import PolymorphicPiStatusRequest
from printnanny_api_client.models.print_nanny_api_config import PrintNannyApiConfig
from printnanny_api_client.models.print_nanny_license import PrintNannyLicense
from printnanny_api_client.models.product import Product
from printnanny_api_client.models.register_request import RegisterRequest
from printnanny_api_client.models.resend_email_verification_request import ResendEmailVerificationRequest
from printnanny_api_client.models.rest_auth_detail import RestAuthDetail
from printnanny_api_client.models.sbc_enum import SbcEnum
from printnanny_api_client.models.stripe_api_error_code import StripeApiErrorCode
from printnanny_api_client.models.stripe_billing_scheme import StripeBillingScheme
from printnanny_api_client.models.stripe_confirmation_method import StripeConfirmationMethod
from printnanny_api_client.models.stripe_customer_tax_exempt import StripeCustomerTaxExempt
from printnanny_api_client.models.stripe_intent_usage import StripeIntentUsage
from printnanny_api_client.models.stripe_payment_intent_cancellation_reason import StripePaymentIntentCancellationReason
from printnanny_api_client.models.stripe_payment_intent_status import StripePaymentIntentStatus
from printnanny_api_client.models.stripe_price_tiers_mode import StripePriceTiersMode
from printnanny_api_client.models.stripe_price_type import StripePriceType
from printnanny_api_client.models.stripe_product_type import StripeProductType
from printnanny_api_client.models.stripe_session_billing_address_collection import StripeSessionBillingAddressCollection
from printnanny_api_client.models.stripe_session_mode import StripeSessionMode
from printnanny_api_client.models.stripe_source_code_verification_status import StripeSourceCodeVerificationStatus
from printnanny_api_client.models.stripe_submit_type_status import StripeSubmitTypeStatus
from printnanny_api_client.models.system_info import SystemInfo
from printnanny_api_client.models.system_info_request import SystemInfoRequest
from printnanny_api_client.models.token import Token
from printnanny_api_client.models.user import User
from printnanny_api_client.models.user_request import UserRequest
from printnanny_api_client.models.verify_email_request import VerifyEmailRequest
from printnanny_api_client.models.webrtc_stream import WebrtcStream
from printnanny_api_client.models.webrtc_stream_request import WebrtcStreamRequest



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import printnanny_api_client
from printnanny_api_client.api.accounts_api import AccountsApi  # noqa: E501
from printnanny_api_client.rest import ApiException


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    def setUp(self):
        self.api = printnanny_api_client.api.accounts_api.AccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accounts2fa_auth_email_create(self):
        """Test case for accounts2fa_auth_email_create

        """
        pass

    def test_accounts2fa_auth_token_create(self):
        """Test case for accounts2fa_auth_token_create

        """
        pass

    def test_accounts_email_waitlist_create(self):
        """Test case for accounts_email_waitlist_create

        """
        pass

    def test_accounts_login_create(self):
        """Test case for accounts_login_create

        """
        pass

    def test_accounts_logout_create(self):
        """Test case for accounts_logout_create

        """
        pass

    def test_accounts_password_change_create(self):
        """Test case for accounts_password_change_create

        """
        pass

    def test_accounts_password_reset_confirm_create(self):
        """Test case for accounts_password_reset_confirm_create

        """
        pass

    def test_accounts_password_reset_create(self):
        """Test case for accounts_password_reset_create

        """
        pass

    def test_accounts_registration_create(self):
        """Test case for accounts_registration_create

        """
        pass

    def test_accounts_registration_resend_email_create(self):
        """Test case for accounts_registration_resend_email_create

        """
        pass

    def test_accounts_registration_verify_email_create(self):
        """Test case for accounts_registration_verify_email_create

        """
        pass

    def test_accounts_user_nkey_retrieve(self):
        """Test case for accounts_user_nkey_retrieve

        """
        pass

    def test_accounts_user_partial_update(self):
        """Test case for accounts_user_partial_update

        """
        pass

    def test_accounts_user_retrieve(self):
        """Test case for accounts_user_retrieve

        """
        pass

    def test_accounts_user_update(self):
        """Test case for accounts_user_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class Order(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_dt': 'datetime',
        'djstripe_checkout_session': 'DjStripeCheckoutSession',
        'djstripe_customer': 'DjStripeCustomer',
        'djstripe_payment_intent': 'DjStripePaymentIntent',
        'email': 'str',
        'id': 'str',
        'is_shippable': 'bool',
        'is_subscription': 'bool',
        'last_status': 'OrderStatus',
        'products': 'list[Product]',
        'status_history': 'list[OrderStatus]',
        'stripe_checkout_redirect_url': 'str',
        'stripe_checkout_session_data': 'dict(str, object)',
        'user': 'User',
        'receipt_url': 'str',
        'portal_url': 'str'
    }

    attribute_map = {
        'created_dt': 'created_dt',
        'djstripe_checkout_session': 'djstripe_checkout_session',
        'djstripe_customer': 'djstripe_customer',
        'djstripe_payment_intent': 'djstripe_payment_intent',
        'email': 'email',
        'id': 'id',
        'is_shippable': 'is_shippable',
        'is_subscription': 'is_subscription',
        'last_status': 'last_status',
        'products': 'products',
        'status_history': 'status_history',
        'stripe_checkout_redirect_url': 'stripe_checkout_redirect_url',
        'stripe_checkout_session_data': 'stripe_checkout_session_data',
        'user': 'user',
        'receipt_url': 'receipt_url',
        'portal_url': 'portal_url'
    }

    def __init__(self, created_dt=None, djstripe_checkout_session=None, djstripe_customer=None, djstripe_payment_intent=None, email=None, id=None, is_shippable=None, is_subscription=None, last_status=None, products=None, status_history=None, stripe_checkout_redirect_url=None, stripe_checkout_session_data=None, user=None, receipt_url=None, portal_url=None, local_vars_configuration=None):  # noqa: E501
        """Order - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_dt = None
        self._djstripe_checkout_session = None
        self._djstripe_customer = None
        self._djstripe_payment_intent = None
        self._email = None
        self._id = None
        self._is_shippable = None
        self._is_subscription = None
        self._last_status = None
        self._products = None
        self._status_history = None
        self._stripe_checkout_redirect_url = None
        self._stripe_checkout_session_data = None
        self._user = None
        self._receipt_url = None
        self._portal_url = None
        self.discriminator = None

        self.created_dt = created_dt
        self.djstripe_checkout_session = djstripe_checkout_session
        self.djstripe_customer = djstripe_customer
        self.djstripe_payment_intent = djstripe_payment_intent
        self.email = email
        self.id = id
        self.is_shippable = is_shippable
        self.is_subscription = is_subscription
        self.last_status = last_status
        self.products = products
        self.status_history = status_history
        self.stripe_checkout_redirect_url = stripe_checkout_redirect_url
        self.stripe_checkout_session_data = stripe_checkout_session_data
        if user is not None:
            self.user = user
        self.receipt_url = receipt_url
        self.portal_url = portal_url

    @property
    def created_dt(self):
        """Gets the created_dt of this Order.  # noqa: E501


        :return: The created_dt of this Order.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this Order.


        :param created_dt: The created_dt of this Order.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def djstripe_checkout_session(self):
        """Gets the djstripe_checkout_session of this Order.  # noqa: E501


        :return: The djstripe_checkout_session of this Order.  # noqa: E501
        :rtype: DjStripeCheckoutSession
        """
        return self._djstripe_checkout_session

    @djstripe_checkout_session.setter
    def djstripe_checkout_session(self, djstripe_checkout_session):
        """Sets the djstripe_checkout_session of this Order.


        :param djstripe_checkout_session: The djstripe_checkout_session of this Order.  # noqa: E501
        :type djstripe_checkout_session: DjStripeCheckoutSession
        """

        self._djstripe_checkout_session = djstripe_checkout_session

    @property
    def djstripe_customer(self):
        """Gets the djstripe_customer of this Order.  # noqa: E501


        :return: The djstripe_customer of this Order.  # noqa: E501
        :rtype: DjStripeCustomer
        """
        return self._djstripe_customer

    @djstripe_customer.setter
    def djstripe_customer(self, djstripe_customer):
        """Sets the djstripe_customer of this Order.


        :param djstripe_customer: The djstripe_customer of this Order.  # noqa: E501
        :type djstripe_customer: DjStripeCustomer
        """

        self._djstripe_customer = djstripe_customer

    @property
    def djstripe_payment_intent(self):
        """Gets the djstripe_payment_intent of this Order.  # noqa: E501


        :return: The djstripe_payment_intent of this Order.  # noqa: E501
        :rtype: DjStripePaymentIntent
        """
        return self._djstripe_payment_intent

    @djstripe_payment_intent.setter
    def djstripe_payment_intent(self, djstripe_payment_intent):
        """Sets the djstripe_payment_intent of this Order.


        :param djstripe_payment_intent: The djstripe_payment_intent of this Order.  # noqa: E501
        :type djstripe_payment_intent: DjStripePaymentIntent
        """

        self._djstripe_payment_intent = djstripe_payment_intent

    @property
    def email(self):
        """Gets the email of this Order.  # noqa: E501


        :return: The email of this Order.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Order.


        :param email: The email of this Order.  # noqa: E501
        :type email: str
        """
        if self.local_vars_configuration.client_side_validation and email is None:  # noqa: E501
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 254):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `254`")  # noqa: E501

        self._email = email

    @property
    def id(self):
        """Gets the id of this Order.  # noqa: E501


        :return: The id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Order.


        :param id: The id of this Order.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def is_shippable(self):
        """Gets the is_shippable of this Order.  # noqa: E501


        :return: The is_shippable of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._is_shippable

    @is_shippable.setter
    def is_shippable(self, is_shippable):
        """Sets the is_shippable of this Order.


        :param is_shippable: The is_shippable of this Order.  # noqa: E501
        :type is_shippable: bool
        """
        if self.local_vars_configuration.client_side_validation and is_shippable is None:  # noqa: E501
            raise ValueError("Invalid value for `is_shippable`, must not be `None`")  # noqa: E501

        self._is_shippable = is_shippable

    @property
    def is_subscription(self):
        """Gets the is_subscription of this Order.  # noqa: E501


        :return: The is_subscription of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._is_subscription

    @is_subscription.setter
    def is_subscription(self, is_subscription):
        """Sets the is_subscription of this Order.


        :param is_subscription: The is_subscription of this Order.  # noqa: E501
        :type is_subscription: bool
        """
        if self.local_vars_configuration.client_side_validation and is_subscription is None:  # noqa: E501
            raise ValueError("Invalid value for `is_subscription`, must not be `None`")  # noqa: E501

        self._is_subscription = is_subscription

    @property
    def last_status(self):
        """Gets the last_status of this Order.  # noqa: E501


        :return: The last_status of this Order.  # noqa: E501
        :rtype: OrderStatus
        """
        return self._last_status

    @last_status.setter
    def last_status(self, last_status):
        """Sets the last_status of this Order.


        :param last_status: The last_status of this Order.  # noqa: E501
        :type last_status: OrderStatus
        """
        if self.local_vars_configuration.client_side_validation and last_status is None:  # noqa: E501
            raise ValueError("Invalid value for `last_status`, must not be `None`")  # noqa: E501

        self._last_status = last_status

    @property
    def products(self):
        """Gets the products of this Order.  # noqa: E501


        :return: The products of this Order.  # noqa: E501
        :rtype: list[Product]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this Order.


        :param products: The products of this Order.  # noqa: E501
        :type products: list[Product]
        """
        if self.local_vars_configuration.client_side_validation and products is None:  # noqa: E501
            raise ValueError("Invalid value for `products`, must not be `None`")  # noqa: E501

        self._products = products

    @property
    def status_history(self):
        """Gets the status_history of this Order.  # noqa: E501


        :return: The status_history of this Order.  # noqa: E501
        :rtype: list[OrderStatus]
        """
        return self._status_history

    @status_history.setter
    def status_history(self, status_history):
        """Sets the status_history of this Order.


        :param status_history: The status_history of this Order.  # noqa: E501
        :type status_history: list[OrderStatus]
        """
        if self.local_vars_configuration.client_side_validation and status_history is None:  # noqa: E501
            raise ValueError("Invalid value for `status_history`, must not be `None`")  # noqa: E501

        self._status_history = status_history

    @property
    def stripe_checkout_redirect_url(self):
        """Gets the stripe_checkout_redirect_url of this Order.  # noqa: E501


        :return: The stripe_checkout_redirect_url of this Order.  # noqa: E501
        :rtype: str
        """
        return self._stripe_checkout_redirect_url

    @stripe_checkout_redirect_url.setter
    def stripe_checkout_redirect_url(self, stripe_checkout_redirect_url):
        """Sets the stripe_checkout_redirect_url of this Order.


        :param stripe_checkout_redirect_url: The stripe_checkout_redirect_url of this Order.  # noqa: E501
        :type stripe_checkout_redirect_url: str
        """
        if self.local_vars_configuration.client_side_validation and stripe_checkout_redirect_url is None:  # noqa: E501
            raise ValueError("Invalid value for `stripe_checkout_redirect_url`, must not be `None`")  # noqa: E501

        self._stripe_checkout_redirect_url = stripe_checkout_redirect_url

    @property
    def stripe_checkout_session_data(self):
        """Gets the stripe_checkout_session_data of this Order.  # noqa: E501


        :return: The stripe_checkout_session_data of this Order.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._stripe_checkout_session_data

    @stripe_checkout_session_data.setter
    def stripe_checkout_session_data(self, stripe_checkout_session_data):
        """Sets the stripe_checkout_session_data of this Order.


        :param stripe_checkout_session_data: The stripe_checkout_session_data of this Order.  # noqa: E501
        :type stripe_checkout_session_data: dict(str, object)
        """
        if self.local_vars_configuration.client_side_validation and stripe_checkout_session_data is None:  # noqa: E501
            raise ValueError("Invalid value for `stripe_checkout_session_data`, must not be `None`")  # noqa: E501

        self._stripe_checkout_session_data = stripe_checkout_session_data

    @property
    def user(self):
        """Gets the user of this Order.  # noqa: E501


        :return: The user of this Order.  # noqa: E501
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Order.


        :param user: The user of this Order.  # noqa: E501
        :type user: User
        """

        self._user = user

    @property
    def receipt_url(self):
        """Gets the receipt_url of this Order.  # noqa: E501


        :return: The receipt_url of this Order.  # noqa: E501
        :rtype: str
        """
        return self._receipt_url

    @receipt_url.setter
    def receipt_url(self, receipt_url):
        """Sets the receipt_url of this Order.


        :param receipt_url: The receipt_url of this Order.  # noqa: E501
        :type receipt_url: str
        """

        self._receipt_url = receipt_url

    @property
    def portal_url(self):
        """Gets the portal_url of this Order.  # noqa: E501


        :return: The portal_url of this Order.  # noqa: E501
        :rtype: str
        """
        return self._portal_url

    @portal_url.setter
    def portal_url(self, portal_url):
        """Sets the portal_url of this Order.


        :param portal_url: The portal_url of this Order.  # noqa: E501
        :type portal_url: str
        """

        self._portal_url = portal_url

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Order):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Order):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.paginated_product_list import PaginatedProductList  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPaginatedProductList(unittest.TestCase):
    """PaginatedProductList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedProductList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.paginated_product_list.PaginatedProductList()  # noqa: E501
        if include_optional :
            return PaginatedProductList(
                count = 123, 
                next = 'http://api.example.org/accounts/?page=4', 
                previous = 'http://api.example.org/accounts/?page=2', 
                results = [
                    printnanny_api_client.models.product.Product(
                        id = '', 
                        djstripe_product = printnanny_api_client.models.dj_stripe_product.DjStripeProduct(
                            djstripe_id = 56, 
                            djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            id = '', 
                            livemode = True, 
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            metadata = {
                                'key' : null
                                }, 
                            description = '', 
                            name = '', 
                            type = null, 
                            active = True, 
                            attributes = {
                                'key' : null
                                }, 
                            caption = '', 
                            deactivate_on = {
                                'key' : null
                                }, 
                            images = {
                                'key' : null
                                }, 
                            package_dimensions = {
                                'key' : null
                                }, 
                            shippable = True, 
                            url = '', 
                            statement_descriptor = '', 
                            unit_label = '', 
                            djstripe_owner_account = '', ), 
                        prices = [
                            printnanny_api_client.models.dj_stripe_price.DjStripePrice(
                                djstripe_id = 56, 
                                billing_scheme = 'per_unit', 
                                human_readable_price = '', 
                                tiers_mode = 'graduated', 
                                djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                livemode = True, 
                                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                description = '', 
                                active = True, 
                                currency = '', 
                                nickname = '', 
                                recurring = {
                                    'key' : null
                                    }, 
                                type = null, 
                                unit_amount = -9223372036854775808, 
                                unit_amount_decimal = '-8072888', 
                                lookup_key = '', 
                                tiers = {
                                    'key' : null
                                    }, 
                                transform_quantity = {
                                    'key' : null
                                    }, 
                                djstripe_owner_account = '', 
                                product = '', )
                            ], 
                        deleted = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        sku = '', 
                        slug = '', 
                        unit_label = '', 
                        name = '', 
                        description = '', 
                        statement_descriptor = '', 
                        images = [
                            ''
                            ], 
                        is_active = True, 
                        is_shippable = True, 
                        is_preorder = True, 
                        is_subscription = True, 
                        stripe_price_lookup_key = '', 
                        stripe_product_id = '', )
                    ]
            )
        else :
            return PaginatedProductList(
        )

    def testPaginatedProductList(self):
        """Test PaginatedProductList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.pi import Pi  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPi(unittest.TestCase):
    """Pi unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Pi
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.pi.Pi()  # noqa: E501
        if include_optional :
            return Pi(
                id = 56, 
                last_boot = '', 
                settings = None, 
                user = None, 
                system_info = None, 
                webrtc_edge = None, 
                webrtc_cloud = None, 
                octoprint_server = None, 
                urls = printnanny_api_client.models.pi_urls.Pi_urls(
                    octoprint = '', 
                    swupdate = '', 
                    syncthing = '', ), 
                nats_app = None, 
                sbc = 'rpi_4', 
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                hostname = '', 
                fqdn = '', 
                favorite = True, 
                setup_finished = True
            )
        else :
            return Pi(
                id = 56,
                last_boot = '',
                settings = None,
                user = None,
                system_info = None,
                webrtc_edge = None,
                webrtc_cloud = None,
                octoprint_server = None,
                urls = printnanny_api_client.models.pi_urls.Pi_urls(
                    octoprint = '', 
                    swupdate = '', 
                    syncthing = '', ),
                nats_app = None,
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )

    def testPi(self):
        """Test Pi"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class DjStripeCustomer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'djstripe_id': 'int',
        'djstripe_created': 'datetime',
        'djstripe_updated': 'datetime',
        'id': 'str',
        'livemode': 'bool',
        'created': 'datetime',
        'metadata': 'dict(str, object)',
        'description': 'str',
        'address': 'dict(str, object)',
        'balance': 'int',
        'currency': 'str',
        'delinquent': 'bool',
        'deleted': 'bool',
        'coupon_start': 'datetime',
        'coupon_end': 'datetime',
        'email': 'str',
        'invoice_prefix': 'str',
        'invoice_settings': 'dict(str, object)',
        'name': 'str',
        'phone': 'str',
        'preferred_locales': 'dict(str, object)',
        'shipping': 'dict(str, object)',
        'tax_exempt': 'StripeCustomerTaxExempt',
        'date_purged': 'datetime',
        'djstripe_owner_account': 'str',
        'default_source': 'str',
        'coupon': 'int',
        'default_payment_method': 'str',
        'subscriber': 'int'
    }

    attribute_map = {
        'djstripe_id': 'djstripe_id',
        'djstripe_created': 'djstripe_created',
        'djstripe_updated': 'djstripe_updated',
        'id': 'id',
        'livemode': 'livemode',
        'created': 'created',
        'metadata': 'metadata',
        'description': 'description',
        'address': 'address',
        'balance': 'balance',
        'currency': 'currency',
        'delinquent': 'delinquent',
        'deleted': 'deleted',
        'coupon_start': 'coupon_start',
        'coupon_end': 'coupon_end',
        'email': 'email',
        'invoice_prefix': 'invoice_prefix',
        'invoice_settings': 'invoice_settings',
        'name': 'name',
        'phone': 'phone',
        'preferred_locales': 'preferred_locales',
        'shipping': 'shipping',
        'tax_exempt': 'tax_exempt',
        'date_purged': 'date_purged',
        'djstripe_owner_account': 'djstripe_owner_account',
        'default_source': 'default_source',
        'coupon': 'coupon',
        'default_payment_method': 'default_payment_method',
        'subscriber': 'subscriber'
    }

    def __init__(self, djstripe_id=None, djstripe_created=None, djstripe_updated=None, id=None, livemode=None, created=None, metadata=None, description=None, address=None, balance=None, currency=None, delinquent=None, deleted=None, coupon_start=None, coupon_end=None, email=None, invoice_prefix=None, invoice_settings=None, name=None, phone=None, preferred_locales=None, shipping=None, tax_exempt=None, date_purged=None, djstripe_owner_account=None, default_source=None, coupon=None, default_payment_method=None, subscriber=None, local_vars_configuration=None):  # noqa: E501
        """DjStripeCustomer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._djstripe_id = None
        self._djstripe_created = None
        self._djstripe_updated = None
        self._id = None
        self._livemode = None
        self._created = None
        self._metadata = None
        self._description = None
        self._address = None
        self._balance = None
        self._currency = None
        self._delinquent = None
        self._deleted = None
        self._coupon_start = None
        self._coupon_end = None
        self._email = None
        self._invoice_prefix = None
        self._invoice_settings = None
        self._name = None
        self._phone = None
        self._preferred_locales = None
        self._shipping = None
        self._tax_exempt = None
        self._date_purged = None
        self._djstripe_owner_account = None
        self._default_source = None
        self._coupon = None
        self._default_payment_method = None
        self._subscriber = None
        self.discriminator = None

        self.djstripe_id = djstripe_id
        self.djstripe_created = djstripe_created
        self.djstripe_updated = djstripe_updated
        self.id = id
        self.livemode = livemode
        self.created = created
        self.metadata = metadata
        self.description = description
        self.address = address
        self.balance = balance
        if currency is not None:
            self.currency = currency
        self.delinquent = delinquent
        self.deleted = deleted
        self.coupon_start = coupon_start
        self.coupon_end = coupon_end
        if email is not None:
            self.email = email
        if invoice_prefix is not None:
            self.invoice_prefix = invoice_prefix
        self.invoice_settings = invoice_settings
        if name is not None:
            self.name = name
        if phone is not None:
            self.phone = phone
        self.preferred_locales = preferred_locales
        self.shipping = shipping
        self.tax_exempt = tax_exempt
        self.date_purged = date_purged
        self.djstripe_owner_account = djstripe_owner_account
        self.default_source = default_source
        self.coupon = coupon
        self.default_payment_method = default_payment_method
        self.subscriber = subscriber

    @property
    def djstripe_id(self):
        """Gets the djstripe_id of this DjStripeCustomer.  # noqa: E501


        :return: The djstripe_id of this DjStripeCustomer.  # noqa: E501
        :rtype: int
        """
        return self._djstripe_id

    @djstripe_id.setter
    def djstripe_id(self, djstripe_id):
        """Sets the djstripe_id of this DjStripeCustomer.


        :param djstripe_id: The djstripe_id of this DjStripeCustomer.  # noqa: E501
        :type djstripe_id: int
        """
        if self.local_vars_configuration.client_side_validation and djstripe_id is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_id`, must not be `None`")  # noqa: E501

        self._djstripe_id = djstripe_id

    @property
    def djstripe_created(self):
        """Gets the djstripe_created of this DjStripeCustomer.  # noqa: E501


        :return: The djstripe_created of this DjStripeCustomer.  # noqa: E501
        :rtype: datetime
        """
        return self._djstripe_created

    @djstripe_created.setter
    def djstripe_created(self, djstripe_created):
        """Sets the djstripe_created of this DjStripeCustomer.


        :param djstripe_created: The djstripe_created of this DjStripeCustomer.  # noqa: E501
        :type djstripe_created: datetime
        """
        if self.local_vars_configuration.client_side_validation and djstripe_created is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_created`, must not be `None`")  # noqa: E501

        self._djstripe_created = djstripe_created

    @property
    def djstripe_updated(self):
        """Gets the djstripe_updated of this DjStripeCustomer.  # noqa: E501


        :return: The djstripe_updated of this DjStripeCustomer.  # noqa: E501
        :rtype: datetime
        """
        return self._djstripe_updated

    @djstripe_updated.setter
    def djstripe_updated(self, djstripe_updated):
        """Sets the djstripe_updated of this DjStripeCustomer.


        :param djstripe_updated: The djstripe_updated of this DjStripeCustomer.  # noqa: E501
        :type djstripe_updated: datetime
        """
        if self.local_vars_configuration.client_side_validation and djstripe_updated is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_updated`, must not be `None`")  # noqa: E501

        self._djstripe_updated = djstripe_updated

    @property
    def id(self):
        """Gets the id of this DjStripeCustomer.  # noqa: E501


        :return: The id of this DjStripeCustomer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DjStripeCustomer.


        :param id: The id of this DjStripeCustomer.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                id is not None and len(id) > 255):
            raise ValueError("Invalid value for `id`, length must be less than or equal to `255`")  # noqa: E501

        self._id = id

    @property
    def livemode(self):
        """Gets the livemode of this DjStripeCustomer.  # noqa: E501

        Null here indicates that the livemode status is unknown or was previously unrecorded. Otherwise, this field indicates whether this record comes from Stripe test mode or live mode operation.  # noqa: E501

        :return: The livemode of this DjStripeCustomer.  # noqa: E501
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """Sets the livemode of this DjStripeCustomer.

        Null here indicates that the livemode status is unknown or was previously unrecorded. Otherwise, this field indicates whether this record comes from Stripe test mode or live mode operation.  # noqa: E501

        :param livemode: The livemode of this DjStripeCustomer.  # noqa: E501
        :type livemode: bool
        """

        self._livemode = livemode

    @property
    def created(self):
        """Gets the created of this DjStripeCustomer.  # noqa: E501

        The datetime this object was created in stripe.  # noqa: E501

        :return: The created of this DjStripeCustomer.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this DjStripeCustomer.

        The datetime this object was created in stripe.  # noqa: E501

        :param created: The created of this DjStripeCustomer.  # noqa: E501
        :type created: datetime
        """

        self._created = created

    @property
    def metadata(self):
        """Gets the metadata of this DjStripeCustomer.  # noqa: E501

        A set of key/value pairs that you can attach to an object. It can be useful for storing additional information about an object in a structured format.  # noqa: E501

        :return: The metadata of this DjStripeCustomer.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this DjStripeCustomer.

        A set of key/value pairs that you can attach to an object. It can be useful for storing additional information about an object in a structured format.  # noqa: E501

        :param metadata: The metadata of this DjStripeCustomer.  # noqa: E501
        :type metadata: dict(str, object)
        """

        self._metadata = metadata

    @property
    def description(self):
        """Gets the description of this DjStripeCustomer.  # noqa: E501

        A description of this object.  # noqa: E501

        :return: The description of this DjStripeCustomer.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DjStripeCustomer.

        A description of this object.  # noqa: E501

        :param description: The description of this DjStripeCustomer.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def address(self):
        """Gets the address of this DjStripeCustomer.  # noqa: E501

        The customer's address.  # noqa: E501

        :return: The address of this DjStripeCustomer.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this DjStripeCustomer.

        The customer's address.  # noqa: E501

        :param address: The address of this DjStripeCustomer.  # noqa: E501
        :type address: dict(str, object)
        """

        self._address = address

    @property
    def balance(self):
        """Gets the balance of this DjStripeCustomer.  # noqa: E501

        Current balance (in cents), if any, being stored on the customer's account. If negative, the customer has credit to apply to the next invoice. If positive, the customer has an amount owed that will be added to the next invoice. The balance does not refer to any unpaid invoices; it solely takes into account amounts that have yet to be successfully applied to any invoice. This balance is only taken into account for recurring billing purposes (i.e., subscriptions, invoices, invoice items).  # noqa: E501

        :return: The balance of this DjStripeCustomer.  # noqa: E501
        :rtype: int
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this DjStripeCustomer.

        Current balance (in cents), if any, being stored on the customer's account. If negative, the customer has credit to apply to the next invoice. If positive, the customer has an amount owed that will be added to the next invoice. The balance does not refer to any unpaid invoices; it solely takes into account amounts that have yet to be successfully applied to any invoice. This balance is only taken into account for recurring billing purposes (i.e., subscriptions, invoices, invoice items).  # noqa: E501

        :param balance: The balance of this DjStripeCustomer.  # noqa: E501
        :type balance: int
        """
        if (self.local_vars_configuration.client_side_validation and
                balance is not None and balance > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `balance`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                balance is not None and balance < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `balance`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._balance = balance

    @property
    def currency(self):
        """Gets the currency of this DjStripeCustomer.  # noqa: E501

        The currency the customer can be charged in for recurring billing purposes  # noqa: E501

        :return: The currency of this DjStripeCustomer.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this DjStripeCustomer.

        The currency the customer can be charged in for recurring billing purposes  # noqa: E501

        :param currency: The currency of this DjStripeCustomer.  # noqa: E501
        :type currency: str
        """
        if (self.local_vars_configuration.client_side_validation and
                currency is not None and len(currency) > 3):
            raise ValueError("Invalid value for `currency`, length must be less than or equal to `3`")  # noqa: E501

        self._currency = currency

    @property
    def delinquent(self):
        """Gets the delinquent of this DjStripeCustomer.  # noqa: E501

        Whether or not the latest charge for the customer's latest invoice has failed.  # noqa: E501

        :return: The delinquent of this DjStripeCustomer.  # noqa: E501
        :rtype: bool
        """
        return self._delinquent

    @delinquent.setter
    def delinquent(self, delinquent):
        """Sets the delinquent of this DjStripeCustomer.

        Whether or not the latest charge for the customer's latest invoice has failed.  # noqa: E501

        :param delinquent: The delinquent of this DjStripeCustomer.  # noqa: E501
        :type delinquent: bool
        """

        self._delinquent = delinquent

    @property
    def deleted(self):
        """Gets the deleted of this DjStripeCustomer.  # noqa: E501

        Whether the Customer instance has been deleted upstream in Stripe or not.  # noqa: E501

        :return: The deleted of this DjStripeCustomer.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this DjStripeCustomer.

        Whether the Customer instance has been deleted upstream in Stripe or not.  # noqa: E501

        :param deleted: The deleted of this DjStripeCustomer.  # noqa: E501
        :type deleted: bool
        """

        self._deleted = deleted

    @property
    def coupon_start(self):
        """Gets the coupon_start of this DjStripeCustomer.  # noqa: E501

        If a coupon is present, the date at which it was applied.  # noqa: E501

        :return: The coupon_start of this DjStripeCustomer.  # noqa: E501
        :rtype: datetime
        """
        return self._coupon_start

    @coupon_start.setter
    def coupon_start(self, coupon_start):
        """Sets the coupon_start of this DjStripeCustomer.

        If a coupon is present, the date at which it was applied.  # noqa: E501

        :param coupon_start: The coupon_start of this DjStripeCustomer.  # noqa: E501
        :type coupon_start: datetime
        """
        if self.local_vars_configuration.client_side_validation and coupon_start is None:  # noqa: E501
            raise ValueError("Invalid value for `coupon_start`, must not be `None`")  # noqa: E501

        self._coupon_start = coupon_start

    @property
    def coupon_end(self):
        """Gets the coupon_end of this DjStripeCustomer.  # noqa: E501

        If a coupon is present and has a limited duration, the date that the discount will end.  # noqa: E501

        :return: The coupon_end of this DjStripeCustomer.  # noqa: E501
        :rtype: datetime
        """
        return self._coupon_end

    @coupon_end.setter
    def coupon_end(self, coupon_end):
        """Sets the coupon_end of this DjStripeCustomer.

        If a coupon is present and has a limited duration, the date that the discount will end.  # noqa: E501

        :param coupon_end: The coupon_end of this DjStripeCustomer.  # noqa: E501
        :type coupon_end: datetime
        """
        if self.local_vars_configuration.client_side_validation and coupon_end is None:  # noqa: E501
            raise ValueError("Invalid value for `coupon_end`, must not be `None`")  # noqa: E501

        self._coupon_end = coupon_end

    @property
    def email(self):
        """Gets the email of this DjStripeCustomer.  # noqa: E501


        :return: The email of this DjStripeCustomer.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this DjStripeCustomer.


        :param email: The email of this DjStripeCustomer.  # noqa: E501
        :type email: str
        """
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 5000):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `5000`")  # noqa: E501

        self._email = email

    @property
    def invoice_prefix(self):
        """Gets the invoice_prefix of this DjStripeCustomer.  # noqa: E501

        The prefix for the customer used to generate unique invoice numbers.  # noqa: E501

        :return: The invoice_prefix of this DjStripeCustomer.  # noqa: E501
        :rtype: str
        """
        return self._invoice_prefix

    @invoice_prefix.setter
    def invoice_prefix(self, invoice_prefix):
        """Sets the invoice_prefix of this DjStripeCustomer.

        The prefix for the customer used to generate unique invoice numbers.  # noqa: E501

        :param invoice_prefix: The invoice_prefix of this DjStripeCustomer.  # noqa: E501
        :type invoice_prefix: str
        """
        if (self.local_vars_configuration.client_side_validation and
                invoice_prefix is not None and len(invoice_prefix) > 255):
            raise ValueError("Invalid value for `invoice_prefix`, length must be less than or equal to `255`")  # noqa: E501

        self._invoice_prefix = invoice_prefix

    @property
    def invoice_settings(self):
        """Gets the invoice_settings of this DjStripeCustomer.  # noqa: E501

        The customer's default invoice settings.  # noqa: E501

        :return: The invoice_settings of this DjStripeCustomer.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._invoice_settings

    @invoice_settings.setter
    def invoice_settings(self, invoice_settings):
        """Sets the invoice_settings of this DjStripeCustomer.

        The customer's default invoice settings.  # noqa: E501

        :param invoice_settings: The invoice_settings of this DjStripeCustomer.  # noqa: E501
        :type invoice_settings: dict(str, object)
        """

        self._invoice_settings = invoice_settings

    @property
    def name(self):
        """Gets the name of this DjStripeCustomer.  # noqa: E501

        The customer's full name or business name.  # noqa: E501

        :return: The name of this DjStripeCustomer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DjStripeCustomer.

        The customer's full name or business name.  # noqa: E501

        :param name: The name of this DjStripeCustomer.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 5000):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `5000`")  # noqa: E501

        self._name = name

    @property
    def phone(self):
        """Gets the phone of this DjStripeCustomer.  # noqa: E501

        The customer's phone number.  # noqa: E501

        :return: The phone of this DjStripeCustomer.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this DjStripeCustomer.

        The customer's phone number.  # noqa: E501

        :param phone: The phone of this DjStripeCustomer.  # noqa: E501
        :type phone: str
        """
        if (self.local_vars_configuration.client_side_validation and
                phone is not None and len(phone) > 5000):
            raise ValueError("Invalid value for `phone`, length must be less than or equal to `5000`")  # noqa: E501

        self._phone = phone

    @property
    def preferred_locales(self):
        """Gets the preferred_locales of this DjStripeCustomer.  # noqa: E501

        The customer's preferred locales (languages), ordered by preference.  # noqa: E501

        :return: The preferred_locales of this DjStripeCustomer.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._preferred_locales

    @preferred_locales.setter
    def preferred_locales(self, preferred_locales):
        """Sets the preferred_locales of this DjStripeCustomer.

        The customer's preferred locales (languages), ordered by preference.  # noqa: E501

        :param preferred_locales: The preferred_locales of this DjStripeCustomer.  # noqa: E501
        :type preferred_locales: dict(str, object)
        """

        self._preferred_locales = preferred_locales

    @property
    def shipping(self):
        """Gets the shipping of this DjStripeCustomer.  # noqa: E501

        Shipping information associated with the customer.  # noqa: E501

        :return: The shipping of this DjStripeCustomer.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._shipping

    @shipping.setter
    def shipping(self, shipping):
        """Sets the shipping of this DjStripeCustomer.

        Shipping information associated with the customer.  # noqa: E501

        :param shipping: The shipping of this DjStripeCustomer.  # noqa: E501
        :type shipping: dict(str, object)
        """

        self._shipping = shipping

    @property
    def tax_exempt(self):
        """Gets the tax_exempt of this DjStripeCustomer.  # noqa: E501

        Describes the customer's tax exemption status. When set to reverse, invoice and receipt PDFs include the text \"Reverse charge\".  # noqa: E501

        :return: The tax_exempt of this DjStripeCustomer.  # noqa: E501
        :rtype: StripeCustomerTaxExempt
        """
        return self._tax_exempt

    @tax_exempt.setter
    def tax_exempt(self, tax_exempt):
        """Sets the tax_exempt of this DjStripeCustomer.

        Describes the customer's tax exemption status. When set to reverse, invoice and receipt PDFs include the text \"Reverse charge\".  # noqa: E501

        :param tax_exempt: The tax_exempt of this DjStripeCustomer.  # noqa: E501
        :type tax_exempt: StripeCustomerTaxExempt
        """

        self._tax_exempt = tax_exempt

    @property
    def date_purged(self):
        """Gets the date_purged of this DjStripeCustomer.  # noqa: E501


        :return: The date_purged of this DjStripeCustomer.  # noqa: E501
        :rtype: datetime
        """
        return self._date_purged

    @date_purged.setter
    def date_purged(self, date_purged):
        """Sets the date_purged of this DjStripeCustomer.


        :param date_purged: The date_purged of this DjStripeCustomer.  # noqa: E501
        :type date_purged: datetime
        """
        if self.local_vars_configuration.client_side_validation and date_purged is None:  # noqa: E501
            raise ValueError("Invalid value for `date_purged`, must not be `None`")  # noqa: E501

        self._date_purged = date_purged

    @property
    def djstripe_owner_account(self):
        """Gets the djstripe_owner_account of this DjStripeCustomer.  # noqa: E501

        The Stripe Account this object belongs to.  # noqa: E501

        :return: The djstripe_owner_account of this DjStripeCustomer.  # noqa: E501
        :rtype: str
        """
        return self._djstripe_owner_account

    @djstripe_owner_account.setter
    def djstripe_owner_account(self, djstripe_owner_account):
        """Sets the djstripe_owner_account of this DjStripeCustomer.

        The Stripe Account this object belongs to.  # noqa: E501

        :param djstripe_owner_account: The djstripe_owner_account of this DjStripeCustomer.  # noqa: E501
        :type djstripe_owner_account: str
        """

        self._djstripe_owner_account = djstripe_owner_account

    @property
    def default_source(self):
        """Gets the default_source of this DjStripeCustomer.  # noqa: E501


        :return: The default_source of this DjStripeCustomer.  # noqa: E501
        :rtype: str
        """
        return self._default_source

    @default_source.setter
    def default_source(self, default_source):
        """Sets the default_source of this DjStripeCustomer.


        :param default_source: The default_source of this DjStripeCustomer.  # noqa: E501
        :type default_source: str
        """

        self._default_source = default_source

    @property
    def coupon(self):
        """Gets the coupon of this DjStripeCustomer.  # noqa: E501


        :return: The coupon of this DjStripeCustomer.  # noqa: E501
        :rtype: int
        """
        return self._coupon

    @coupon.setter
    def coupon(self, coupon):
        """Sets the coupon of this DjStripeCustomer.


        :param coupon: The coupon of this DjStripeCustomer.  # noqa: E501
        :type coupon: int
        """

        self._coupon = coupon

    @property
    def default_payment_method(self):
        """Gets the default_payment_method of this DjStripeCustomer.  # noqa: E501

        default payment method used for subscriptions and invoices for the customer.  # noqa: E501

        :return: The default_payment_method of this DjStripeCustomer.  # noqa: E501
        :rtype: str
        """
        return self._default_payment_method

    @default_payment_method.setter
    def default_payment_method(self, default_payment_method):
        """Sets the default_payment_method of this DjStripeCustomer.

        default payment method used for subscriptions and invoices for the customer.  # noqa: E501

        :param default_payment_method: The default_payment_method of this DjStripeCustomer.  # noqa: E501
        :type default_payment_method: str
        """

        self._default_payment_method = default_payment_method

    @property
    def subscriber(self):
        """Gets the subscriber of this DjStripeCustomer.  # noqa: E501


        :return: The subscriber of this DjStripeCustomer.  # noqa: E501
        :rtype: int
        """
        return self._subscriber

    @subscriber.setter
    def subscriber(self, subscriber):
        """Sets the subscriber of this DjStripeCustomer.


        :param subscriber: The subscriber of this DjStripeCustomer.  # noqa: E501
        :type subscriber: int
        """

        self._subscriber = subscriber

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DjStripeCustomer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DjStripeCustomer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class WebrtcStream(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active': 'bool',
        'admin_port': 'int',
        'admin_secret': 'str',
        'admin_url': 'str',
        'api_domain': 'str',
        'api_port': 'int',
        'api_token': 'str',
        'api_url': 'str',
        'config_type': 'JanusConfigType',
        'created_dt': 'datetime',
        'id': 'int',
        'info': 'dict(str, object)',
        'is_admin': 'bool',
        'pi': 'int',
        'pt': 'int',
        'rtp_domain': 'str',
        'video_rtp_port': 'int',
        'data_rtp_port': 'int',
        'rtpmap': 'str',
        'stream_pin': 'str',
        'stream_secret': 'str',
        'updated_dt': 'datetime',
        'ws_port': 'int',
        'ws_url': 'str'
    }

    attribute_map = {
        'active': 'active',
        'admin_port': 'admin_port',
        'admin_secret': 'admin_secret',
        'admin_url': 'admin_url',
        'api_domain': 'api_domain',
        'api_port': 'api_port',
        'api_token': 'api_token',
        'api_url': 'api_url',
        'config_type': 'config_type',
        'created_dt': 'created_dt',
        'id': 'id',
        'info': 'info',
        'is_admin': 'is_admin',
        'pi': 'pi',
        'pt': 'pt',
        'rtp_domain': 'rtp_domain',
        'video_rtp_port': 'video_rtp_port',
        'data_rtp_port': 'data_rtp_port',
        'rtpmap': 'rtpmap',
        'stream_pin': 'stream_pin',
        'stream_secret': 'stream_secret',
        'updated_dt': 'updated_dt',
        'ws_port': 'ws_port',
        'ws_url': 'ws_url'
    }

    def __init__(self, active=None, admin_port=None, admin_secret=None, admin_url=None, api_domain=None, api_port=None, api_token=None, api_url=None, config_type=None, created_dt=None, id=None, info=None, is_admin=None, pi=None, pt=None, rtp_domain=None, video_rtp_port=None, data_rtp_port=None, rtpmap=None, stream_pin=None, stream_secret=None, updated_dt=None, ws_port=None, ws_url=None, local_vars_configuration=None):  # noqa: E501
        """WebrtcStream - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._active = None
        self._admin_port = None
        self._admin_secret = None
        self._admin_url = None
        self._api_domain = None
        self._api_port = None
        self._api_token = None
        self._api_url = None
        self._config_type = None
        self._created_dt = None
        self._id = None
        self._info = None
        self._is_admin = None
        self._pi = None
        self._pt = None
        self._rtp_domain = None
        self._video_rtp_port = None
        self._data_rtp_port = None
        self._rtpmap = None
        self._stream_pin = None
        self._stream_secret = None
        self._updated_dt = None
        self._ws_port = None
        self._ws_url = None
        self.discriminator = None

        if active is not None:
            self.active = active
        self.admin_port = admin_port
        self.admin_secret = admin_secret
        self.admin_url = admin_url
        self.api_domain = api_domain
        self.api_port = api_port
        self.api_token = api_token
        self.api_url = api_url
        if config_type is not None:
            self.config_type = config_type
        self.created_dt = created_dt
        self.id = id
        self.info = info
        self.is_admin = is_admin
        self.pi = pi
        self.pt = pt
        self.rtp_domain = rtp_domain
        self.video_rtp_port = video_rtp_port
        self.data_rtp_port = data_rtp_port
        self.rtpmap = rtpmap
        self.stream_pin = stream_pin
        self.stream_secret = stream_secret
        self.updated_dt = updated_dt
        self.ws_port = ws_port
        self.ws_url = ws_url

    @property
    def active(self):
        """Gets the active of this WebrtcStream.  # noqa: E501


        :return: The active of this WebrtcStream.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this WebrtcStream.


        :param active: The active of this WebrtcStream.  # noqa: E501
        :type active: bool
        """

        self._active = active

    @property
    def admin_port(self):
        """Gets the admin_port of this WebrtcStream.  # noqa: E501


        :return: The admin_port of this WebrtcStream.  # noqa: E501
        :rtype: int
        """
        return self._admin_port

    @admin_port.setter
    def admin_port(self, admin_port):
        """Sets the admin_port of this WebrtcStream.


        :param admin_port: The admin_port of this WebrtcStream.  # noqa: E501
        :type admin_port: int
        """
        if self.local_vars_configuration.client_side_validation and admin_port is None:  # noqa: E501
            raise ValueError("Invalid value for `admin_port`, must not be `None`")  # noqa: E501

        self._admin_port = admin_port

    @property
    def admin_secret(self):
        """Gets the admin_secret of this WebrtcStream.  # noqa: E501


        :return: The admin_secret of this WebrtcStream.  # noqa: E501
        :rtype: str
        """
        return self._admin_secret

    @admin_secret.setter
    def admin_secret(self, admin_secret):
        """Sets the admin_secret of this WebrtcStream.


        :param admin_secret: The admin_secret of this WebrtcStream.  # noqa: E501
        :type admin_secret: str
        """
        if self.local_vars_configuration.client_side_validation and admin_secret is None:  # noqa: E501
            raise ValueError("Invalid value for `admin_secret`, must not be `None`")  # noqa: E501

        self._admin_secret = admin_secret

    @property
    def admin_url(self):
        """Gets the admin_url of this WebrtcStream.  # noqa: E501


        :return: The admin_url of this WebrtcStream.  # noqa: E501
        :rtype: str
        """
        return self._admin_url

    @admin_url.setter
    def admin_url(self, admin_url):
        """Sets the admin_url of this WebrtcStream.


        :param admin_url: The admin_url of this WebrtcStream.  # noqa: E501
        :type admin_url: str
        """
        if self.local_vars_configuration.client_side_validation and admin_url is None:  # noqa: E501
            raise ValueError("Invalid value for `admin_url`, must not be `None`")  # noqa: E501

        self._admin_url = admin_url

    @property
    def api_domain(self):
        """Gets the api_domain of this WebrtcStream.  # noqa: E501


        :return: The api_domain of this WebrtcStream.  # noqa: E501
        :rtype: str
        """
        return self._api_domain

    @api_domain.setter
    def api_domain(self, api_domain):
        """Sets the api_domain of this WebrtcStream.


        :param api_domain: The api_domain of this WebrtcStream.  # noqa: E501
        :type api_domain: str
        """
        if self.local_vars_configuration.client_side_validation and api_domain is None:  # noqa: E501
            raise ValueError("Invalid value for `api_domain`, must not be `None`")  # noqa: E501

        self._api_domain = api_domain

    @property
    def api_port(self):
        """Gets the api_port of this WebrtcStream.  # noqa: E501


        :return: The api_port of this WebrtcStream.  # noqa: E501
        :rtype: int
        """
        return self._api_port

    @api_port.setter
    def api_port(self, api_port):
        """Sets the api_port of this WebrtcStream.


        :param api_port: The api_port of this WebrtcStream.  # noqa: E501
        :type api_port: int
        """
        if self.local_vars_configuration.client_side_validation and api_port is None:  # noqa: E501
            raise ValueError("Invalid value for `api_port`, must not be `None`")  # noqa: E501

        self._api_port = api_port

    @property
    def api_token(self):
        """Gets the api_token of this WebrtcStream.  # noqa: E501


        :return: The api_token of this WebrtcStream.  # noqa: E501
        :rtype: str
        """
        return self._api_token

    @api_token.setter
    def api_token(self, api_token):
        """Sets the api_token of this WebrtcStream.


        :param api_token: The api_token of this WebrtcStream.  # noqa: E501
        :type api_token: str
        """
        if self.local_vars_configuration.client_side_validation and api_token is None:  # noqa: E501
            raise ValueError("Invalid value for `api_token`, must not be `None`")  # noqa: E501

        self._api_token = api_token

    @property
    def api_url(self):
        """Gets the api_url of this WebrtcStream.  # noqa: E501


        :return: The api_url of this WebrtcStream.  # noqa: E501
        :rtype: str
        """
        return self._api_url

    @api_url.setter
    def api_url(self, api_url):
        """Sets the api_url of this WebrtcStream.


        :param api_url: The api_url of this WebrtcStream.  # noqa: E501
        :type api_url: str
        """
        if self.local_vars_configuration.client_side_validation and api_url is None:  # noqa: E501
            raise ValueError("Invalid value for `api_url`, must not be `None`")  # noqa: E501

        self._api_url = api_url

    @property
    def config_type(self):
        """Gets the config_type of this WebrtcStream.  # noqa: E501


        :return: The config_type of this WebrtcStream.  # noqa: E501
        :rtype: JanusConfigType
        """
        return self._config_type

    @config_type.setter
    def config_type(self, config_type):
        """Sets the config_type of this WebrtcStream.


        :param config_type: The config_type of this WebrtcStream.  # noqa: E501
        :type config_type: JanusConfigType
        """

        self._config_type = config_type

    @property
    def created_dt(self):
        """Gets the created_dt of this WebrtcStream.  # noqa: E501


        :return: The created_dt of this WebrtcStream.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this WebrtcStream.


        :param created_dt: The created_dt of this WebrtcStream.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def id(self):
        """Gets the id of this WebrtcStream.  # noqa: E501


        :return: The id of this WebrtcStream.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebrtcStream.


        :param id: The id of this WebrtcStream.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def info(self):
        """Gets the info of this WebrtcStream.  # noqa: E501


        :return: The info of this WebrtcStream.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._info

    @info.setter
    def info(self, info):
        """Sets the info of this WebrtcStream.


        :param info: The info of this WebrtcStream.  # noqa: E501
        :type info: dict(str, object)
        """
        if self.local_vars_configuration.client_side_validation and info is None:  # noqa: E501
            raise ValueError("Invalid value for `info`, must not be `None`")  # noqa: E501

        self._info = info

    @property
    def is_admin(self):
        """Gets the is_admin of this WebrtcStream.  # noqa: E501


        :return: The is_admin of this WebrtcStream.  # noqa: E501
        :rtype: bool
        """
        return self._is_admin

    @is_admin.setter
    def is_admin(self, is_admin):
        """Sets the is_admin of this WebrtcStream.


        :param is_admin: The is_admin of this WebrtcStream.  # noqa: E501
        :type is_admin: bool
        """
        if self.local_vars_configuration.client_side_validation and is_admin is None:  # noqa: E501
            raise ValueError("Invalid value for `is_admin`, must not be `None`")  # noqa: E501

        self._is_admin = is_admin

    @property
    def pi(self):
        """Gets the pi of this WebrtcStream.  # noqa: E501


        :return: The pi of this WebrtcStream.  # noqa: E501
        :rtype: int
        """
        return self._pi

    @pi.setter
    def pi(self, pi):
        """Sets the pi of this WebrtcStream.


        :param pi: The pi of this WebrtcStream.  # noqa: E501
        :type pi: int
        """
        if self.local_vars_configuration.client_side_validation and pi is None:  # noqa: E501
            raise ValueError("Invalid value for `pi`, must not be `None`")  # noqa: E501

        self._pi = pi

    @property
    def pt(self):
        """Gets the pt of this WebrtcStream.  # noqa: E501


        :return: The pt of this WebrtcStream.  # noqa: E501
        :rtype: int
        """
        return self._pt

    @pt.setter
    def pt(self, pt):
        """Sets the pt of this WebrtcStream.


        :param pt: The pt of this WebrtcStream.  # noqa: E501
        :type pt: int
        """
        if self.local_vars_configuration.client_side_validation and pt is None:  # noqa: E501
            raise ValueError("Invalid value for `pt`, must not be `None`")  # noqa: E501

        self._pt = pt

    @property
    def rtp_domain(self):
        """Gets the rtp_domain of this WebrtcStream.  # noqa: E501


        :return: The rtp_domain of this WebrtcStream.  # noqa: E501
        :rtype: str
        """
        return self._rtp_domain

    @rtp_domain.setter
    def rtp_domain(self, rtp_domain):
        """Sets the rtp_domain of this WebrtcStream.


        :param rtp_domain: The rtp_domain of this WebrtcStream.  # noqa: E501
        :type rtp_domain: str
        """
        if self.local_vars_configuration.client_side_validation and rtp_domain is None:  # noqa: E501
            raise ValueError("Invalid value for `rtp_domain`, must not be `None`")  # noqa: E501

        self._rtp_domain = rtp_domain

    @property
    def video_rtp_port(self):
        """Gets the video_rtp_port of this WebrtcStream.  # noqa: E501


        :return: The video_rtp_port of this WebrtcStream.  # noqa: E501
        :rtype: int
        """
        return self._video_rtp_port

    @video_rtp_port.setter
    def video_rtp_port(self, video_rtp_port):
        """Sets the video_rtp_port of this WebrtcStream.


        :param video_rtp_port: The video_rtp_port of this WebrtcStream.  # noqa: E501
        :type video_rtp_port: int
        """

        self._video_rtp_port = video_rtp_port

    @property
    def data_rtp_port(self):
        """Gets the data_rtp_port of this WebrtcStream.  # noqa: E501


        :return: The data_rtp_port of this WebrtcStream.  # noqa: E501
        :rtype: int
        """
        return self._data_rtp_port

    @data_rtp_port.setter
    def data_rtp_port(self, data_rtp_port):
        """Sets the data_rtp_port of this WebrtcStream.


        :param data_rtp_port: The data_rtp_port of this WebrtcStream.  # noqa: E501
        :type data_rtp_port: int
        """

        self._data_rtp_port = data_rtp_port

    @property
    def rtpmap(self):
        """Gets the rtpmap of this WebrtcStream.  # noqa: E501


        :return: The rtpmap of this WebrtcStream.  # noqa: E501
        :rtype: str
        """
        return self._rtpmap

    @rtpmap.setter
    def rtpmap(self, rtpmap):
        """Sets the rtpmap of this WebrtcStream.


        :param rtpmap: The rtpmap of this WebrtcStream.  # noqa: E501
        :type rtpmap: str
        """
        if self.local_vars_configuration.client_side_validation and rtpmap is None:  # noqa: E501
            raise ValueError("Invalid value for `rtpmap`, must not be `None`")  # noqa: E501

        self._rtpmap = rtpmap

    @property
    def stream_pin(self):
        """Gets the stream_pin of this WebrtcStream.  # noqa: E501


        :return: The stream_pin of this WebrtcStream.  # noqa: E501
        :rtype: str
        """
        return self._stream_pin

    @stream_pin.setter
    def stream_pin(self, stream_pin):
        """Sets the stream_pin of this WebrtcStream.


        :param stream_pin: The stream_pin of this WebrtcStream.  # noqa: E501
        :type stream_pin: str
        """
        if self.local_vars_configuration.client_side_validation and stream_pin is None:  # noqa: E501
            raise ValueError("Invalid value for `stream_pin`, must not be `None`")  # noqa: E501

        self._stream_pin = stream_pin

    @property
    def stream_secret(self):
        """Gets the stream_secret of this WebrtcStream.  # noqa: E501


        :return: The stream_secret of this WebrtcStream.  # noqa: E501
        :rtype: str
        """
        return self._stream_secret

    @stream_secret.setter
    def stream_secret(self, stream_secret):
        """Sets the stream_secret of this WebrtcStream.


        :param stream_secret: The stream_secret of this WebrtcStream.  # noqa: E501
        :type stream_secret: str
        """
        if self.local_vars_configuration.client_side_validation and stream_secret is None:  # noqa: E501
            raise ValueError("Invalid value for `stream_secret`, must not be `None`")  # noqa: E501

        self._stream_secret = stream_secret

    @property
    def updated_dt(self):
        """Gets the updated_dt of this WebrtcStream.  # noqa: E501


        :return: The updated_dt of this WebrtcStream.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this WebrtcStream.


        :param updated_dt: The updated_dt of this WebrtcStream.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def ws_port(self):
        """Gets the ws_port of this WebrtcStream.  # noqa: E501


        :return: The ws_port of this WebrtcStream.  # noqa: E501
        :rtype: int
        """
        return self._ws_port

    @ws_port.setter
    def ws_port(self, ws_port):
        """Sets the ws_port of this WebrtcStream.


        :param ws_port: The ws_port of this WebrtcStream.  # noqa: E501
        :type ws_port: int
        """
        if self.local_vars_configuration.client_side_validation and ws_port is None:  # noqa: E501
            raise ValueError("Invalid value for `ws_port`, must not be `None`")  # noqa: E501

        self._ws_port = ws_port

    @property
    def ws_url(self):
        """Gets the ws_url of this WebrtcStream.  # noqa: E501


        :return: The ws_url of this WebrtcStream.  # noqa: E501
        :rtype: str
        """
        return self._ws_url

    @ws_url.setter
    def ws_url(self, ws_url):
        """Sets the ws_url of this WebrtcStream.


        :param ws_url: The ws_url of this WebrtcStream.  # noqa: E501
        :type ws_url: str
        """
        if self.local_vars_configuration.client_side_validation and ws_url is None:  # noqa: E501
            raise ValueError("Invalid value for `ws_url`, must not be `None`")  # noqa: E501

        self._ws_url = ws_url

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebrtcStream):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebrtcStream):
            return True

        return self.to_dict() != other.to_dict()
